(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    216037,       6813]*)
(*NotebookOutlinePosition[    216942,       6842]*)
(*  CellTagsIndexPosition[    216898,       6838]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Electromagnet Undulator", "Title",
  TextAlignment->Center],

Cell["Version 1.0 December 2000 by P. Elleaume", "Text"],

Cell["\<\
This is a simple demonstration notebook which builds a  4 periods \
of an electromagnet undulator . Note that this undulator is unphysical \
because it has been generated  over a finite length assuming the symmetry of \
an infinitely long undulator. Nevertheless the field around the centre \
{0,0,0} should be close to the reality while the field in the extremities is \
COMPLETELY WRONG. The purpose of this notebook is to answer questions like :
What peak field can be produced by an electro-magnet undulator ? 
What is the electrical power needed ?
What is the saturation characteristics of such an undulator (Peak field vs \
Current ) ?\
\>", "Text"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(<< Radia`\), "\[IndentingNewLine]", 
    \(\(Off[General::"\<spell1\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Radia Version: "\[InvisibleSpace]4.098`\
\[InvisibleSpace]" is loaded"\),
      SequenceForm[ "Radia Version: ", 4.0979999999999999, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright Wolfram \
Research, Inc."\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Function", "Section"],

Cell[BoxData[
    \(\(und[] := 
        Module[{}, \[IndentingNewLine]\[IndentingNewLine]m1 = 
            radObjRecMag[{lx/4, lyp/4, gap/2 + lzp/2}, {lx/2, lyp/2, lzp}]; 
          radObjDivMag[m1, {nx, ny, nz}]; \[IndentingNewLine]m2 = 
            radObjRecMag[{lx/4, lyp/4, gap/2 + lzp + lzy/2}, {lx/2, lyp/2, 
                lzy}]; \[IndentingNewLine]\[IndentingNewLine]c = {0, 
              lyp/2 + 0.01, gap/2 + lzp}; \[IndentingNewLine]c1 = {0, 0, 
              gap/2 + lzp}; \[IndentingNewLine]radObjDivMag[
            m2, {ny, nr, nx}, {"\<cyl\>", {c, {1, 0, 0}}, c1, 
              2*lzy/lyp}]; \[IndentingNewLine]\[IndentingNewLine]m3 = 
            radObjRecMag[{lx/4, per/8 + lyp/4, gap/2 + lzp + lzy/2}, {lx/2, 
                per/4 - lyp/2, 
                lzy}]; \[IndentingNewLine]\[IndentingNewLine]radObjDivMag[
            m3, {nx, nyy, ny}]; \[IndentingNewLine]\[IndentingNewLine]yoke = 
            radObjCnt[{m1, m2, m3}]; \[IndentingNewLine]radObjDrwAtr[yoke, 
            colyoke]; \[IndentingNewLine]radMatApl[yoke, 
            mat]; \[IndentingNewLine]\[IndentingNewLine]RadTrfZerPerp[
            yoke, {0, 0, 0}, {1, 0, 
              0}]; \[IndentingNewLine]\[IndentingNewLine]RadTrfZerPerp[
            yoke, {0, 0, 0}, {0, 1, 0}]; \[IndentingNewLine]dx = lx; 
          dy = lyp/2 + 2*air; 
          dz = lzp - 2*air; \[IndentingNewLine]rmin = lyp/4; 
          rmax = lyp/4 + per/4 - lyp/2 - air; \[IndentingNewLine]coil = 
            radObjRaceTrk[{0, 0, gap/2 + lzp/2}, {rmin, rmax}, {dx, dy}, dz, 
              3, curdens]; \[IndentingNewLine]radObjDrwAtr[coil, 
            colcoil]; \[IndentingNewLine]tot = 
            radObjCnt[{yoke, coil}]; \[IndentingNewLine]yok = 
            radObjCnt[{yoke, coil}]; \[IndentingNewLine]RadTrfZerPara[
            tot, {0, 0, 0}, {0, 0, 1}]; \[IndentingNewLine]RadTrfZerPara[
            tot, {0, per/4, 0}, {0, 1, 0}]; \[IndentingNewLine]RadTrfZerPara[
            tot, {0, \(-per\)/4, 0}, {0, 1, 
              0}]; \[IndentingNewLine]\[IndentingNewLine]RadTrfZerPara[
            tot, {0, 3*per/4, 0}, {0, 1, 
              0}]; \[IndentingNewLine]\[IndentingNewLine]pow = 
            4000/per*curdens^2*ro*
              dz*\((\[Pi]*\((rmax^2 - rmin^2)\) + 
                  2*\((rmax - rmin)\)*\((dx + 
                        dy)\))\); \[IndentingNewLine]\[IndentingNewLine]{\
\[IndentingNewLine]ElecPower \[Rule] pow, \ \ \ \  (*\ 
              Power/m\ in\ kW\ *) \[IndentingNewLine]Reference \[Rule] 
              tot, \[IndentingNewLine]Yoke \[Rule] 
              yoke, \[IndentingNewLine]Coil \[Rule] 
              coil\[IndentingNewLine]}\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solve", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(radUtiDelAll[];\)\[IndentingNewLine] (*___  ___  ___  ___  ___  ___  \
___  ___  ___  ___  ___  ___  ___  ___  ___  ___  ___  _*) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(per = 230;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Undulator\ Period\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(gap = 50;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Magnetic\ Gap\ [mm]\ \ *) \), "\[IndentingNewLine]", 
    \(\(lx = 
        200;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ Width\ of\ the\ \
Pole\ [mm]\ \ *) \), "\[IndentingNewLine]", 
    \(\(air = 
        0.1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ \ air\ gap\ between\ \
coil\ and\ yoke\ [mm]\ \ *) \), "\[IndentingNewLine]", 
    \(\(lyp = per*0.2;\)\ \ \  (*\ 
      Length\ of\ pole\ along\ the\ beam\ [
          mm]\ \ *) \), "\[IndentingNewLine]", 
    \(\(lzp = 200;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      vertical\ height\ of\ pole\ [mm]\ \ *) \), "\[IndentingNewLine]", 
    \(\(lzy = lyp;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      height\ of\ the\ return\ yoke\ [mm]\ \ *) \), "\[IndentingNewLine]", 
    \(\(curdens = 2;\)\ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Current\ density\ in\ coil\ [A/mm2]\ \ *) \), "\[IndentingNewLine]", 
    \(\(ro = 1.7\ \ 10^\(-8\);\)\ \ \ \ \ \ \ \ \  (*\ 
      resistivity\ of\ the\ coil\ conductor\ [
          Ohm - m]\ *) \), "\[IndentingNewLine]", 
    \(\(mat = RadMatXc06[]\ ;\)\ \ \  (*\ 
      Material\ of\ the\ yoke\ *) \[IndentingNewLine] (*___  ___  ___  ___  \
___  ___  ___  ___  ___  ___  ___  ___  ___  ___  ___  ___  ___  _*) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(nx = 2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ segmentation\ parameter\ in\ pole\ *) \), "\
\[IndentingNewLine]", 
    \(\(ny = 3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Longitudinal\ segmentation\ parameter\ in\ pole\ *) \), "\
\[IndentingNewLine]", 
    \(\(nz = 6;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ \ segmentation\ parameter\ in\ pole\ *) \), "\
\[IndentingNewLine]", 
    \(\(nyy = 2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Long . \ segmentation\ parameter\ in\ the\ return\ of\ the\ yoke\ *) \
\), "\[IndentingNewLine]", 
    \(\(nr = 2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Radial\ segmentation\ parameter\ in\ the\ corner\ of\ the\ yoke\ *) \
\[IndentingNewLine]\[IndentingNewLine] (*___  ___  ___  ___  ___  ___  ___  \
___  ___  ___  ___  ___  ___  ___  ___  ___  ___  _*) \[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(colyoke = {0, 0.5, 1};\)\ \ \  (*\ 
      RGB\ color\ of\ the\ yoke\ *) \), "\[IndentingNewLine]", 
    \(\(colcoil = {1, 0, 0};\)\ \ \ \ \ \ \ \  (*\ 
      RGB\ color\ of\ the\ coil\ *) \[IndentingNewLine]\[IndentingNewLine] \
(*___  ___  ___  ___  ___  ___  ___  ___  ___  ___  ___  ___  ___  ___  ___  \
___  ___  _*) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(t = und[];\)\), "\[IndentingNewLine]", 
    \(\(tt = Reference /. t;\)\), "\[IndentingNewLine]", 
    \(\(pow = ElecPower /. t;\)\), "\[IndentingNewLine]", 
    \(prec = 1.0\ 10^\(-5\); niter = 1000; 
    RadSolve[tt, prec, niter];\), "\[IndentingNewLine]", 
    \(\(bz = 
        radFld[tt, "\<Bz\>", {0, 0, 
            0}];\)\[IndentingNewLine]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Electrical Power/Length = \>", 
        pow, "\< kW\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Peak Field = \>", bz, "\< T\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Electrical Power/Length = \
"\[InvisibleSpace]5.094172995297352`\[InvisibleSpace]" kW"\),
      SequenceForm[ "Electrical Power/Length = ", 5.0941729952973516, " kW"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Peak Field = "\[InvisibleSpace]0.4572112933728246`\
\[InvisibleSpace]" T"\),
      SequenceForm[ "Peak Field = ", 0.45721129337282462, " T"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics", "Section"],

Cell[BoxData[
    \(\(radObjDrwQD3D[tt];\)\)], "Input"],

Cell[BoxData[
    \(\(radObjDrwQD3D[Yoke /. t];\)\)], "Input"],

Cell[BoxData[
    \(\(radObjDrwQD3D[Coil /. t];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(RadPlot3DOptions[];\)\), "\n", 
    \(\(Show[Graphics3D[radObjDrw[Yoke /. t]]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.22651 .23795 -30.25 -8.63484 ]
[.22651 .23795 0 5.36516 ]
[.28318 .18868 -24.25 -8.70776 ]
[.28318 .18868 0 5.29224 ]
[.34395 .13586 -10 -8.7875 ]
[.34395 .13586 0 5.2125 ]
[.40927 .07907 -16 -8.87504 ]
[.40927 .07907 0 5.12496 ]
[.47966 .01788 -22 -8.97159 ]
[.47966 .01788 0 5.02841 ]
[.28339 .12039 -15.625 -8.7875 ]
[.28339 .12039 0 5.2125 ]
[.52564 .00994 -12.1647 -14 ]
[.52564 .00994 12.0853 0 ]
[.58874 .02784 -12.262 -14 ]
[.58874 .02784 11.988 0 ]
[.65047 .04535 -5.09561 -14 ]
[.65047 .04535 4.90439 0 ]
[.71088 .06248 -8.21393 -14 ]
[.71088 .06248 7.78607 0 ]
[.77 .07924 -8.27332 -14 ]
[.77 .07924 7.72668 0 ]
[.64928 -0.01714 -7.96189 -14 ]
[.64928 -0.01714 7.66311 0 ]
[.81457 .31103 0 -5.28291 ]
[.81457 .31103 22 8.71709 ]
[.82488 .58432 0 -5.63014 ]
[.82488 .58432 22 8.36986 ]
[.88045 .4535 0 -5.44655 ]
[.88045 .4535 14.3125 8.55345 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.23322 .24553 m
.49903 .0149 L
s
.25 Mabswid
.23868 .24079 m
.24476 .24221 L
s
gsave
.22651 .23795 -91.25 -12.6348 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.29533 .19164 m
.3014 .19312 L
s
gsave
.28318 .18868 -85.25 -12.7078 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.35606 .13895 m
.36212 .14049 L
s
gsave
.34395 .13586 -71 -12.7875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.42134 .08231 m
.42738 .08393 L
s
gsave
.40927 .07907 -77 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.4917 .02127 m
.49771 .02296 L
s
gsave
.47966 .01788 -83 -12.9716 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.2497 .23123 m
.25335 .23209 L
s
.26087 .22153 m
.26452 .2224 L
s
.2722 .21171 m
.27585 .21258 L
s
.28368 .20174 m
.28733 .20263 L
s
.30713 .1814 m
.31077 .1823 L
s
.3191 .17101 m
.32274 .17192 L
s
.33125 .16048 m
.33489 .16139 L
s
.34356 .14979 m
.3472 .15071 L
s
.36874 .12795 m
.37237 .12889 L
s
.3816 .11679 m
.38523 .11773 L
s
.39465 .10547 m
.39828 .10642 L
s
.4079 .09397 m
.41152 .09494 L
s
.43499 .07047 m
.43861 .07145 L
s
.44884 .05845 m
.45246 .05944 L
s
.46291 .04624 m
.46652 .04724 L
s
.47719 .03385 m
.4808 .03486 L
s
gsave
.28339 .12039 -76.625 -12.7875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.49903 .0149 m
.79464 .09859 L
s
.25 Mabswid
.52568 .02244 m
.5257 .02869 L
s
gsave
.52564 .00994 -73.1647 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.58888 .04034 m
.58895 .04659 L
s
gsave
.58874 .02784 -73.262 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.65071 .05784 m
.65083 .06409 L
s
gsave
.65047 .04535 -66.0956 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.71121 .07497 m
.71138 .08122 L
s
gsave
.71088 .06248 -69.2139 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.77043 .09174 m
.77064 .09798 L
s
gsave
.77 .07924 -69.2733 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.53843 .02605 m
.53845 .0298 L
s
.55113 .02965 m
.55115 .0334 L
s
.56377 .03323 m
.5638 .03698 L
s
.57635 .03679 m
.57639 .04054 L
s
.60135 .04387 m
.6014 .04762 L
s
.61377 .04739 m
.61383 .05114 L
s
.62614 .05089 m
.6262 .05464 L
s
.63845 .05437 m
.63852 .05812 L
s
.66292 .0613 m
.66299 .06505 L
s
.67507 .06474 m
.67515 .06849 L
s
.68717 .06816 m
.68726 .07191 L
s
.69922 .07158 m
.69931 .07532 L
s
.72316 .07835 m
.72327 .0821 L
s
.73505 .08172 m
.73516 .08547 L
s
.7469 .08507 m
.74701 .08882 L
s
.75869 .08841 m
.75881 .09216 L
s
.51287 .01882 m
.51287 .02257 L
s
.5 .01517 m
.5 .01892 L
s
.78212 .09505 m
.78226 .0988 L
s
.79377 .09834 m
.79391 .10209 L
s
gsave
.64928 -0.01714 -68.9619 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.79464 .09859 m
.82095 .80615 L
s
.25 Mabswid
.80243 .30805 m
.79636 .30657 L
s
gsave
.81457 .31103 -61 -9.28291 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.81261 .58192 m
.80648 .58072 L
s
gsave
.82488 .58432 -61 -9.63014 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.80441 .36139 m
.80076 .36053 L
s
.80642 .41543 m
.80276 .41461 L
s
.80846 .47019 m
.80479 .4694 L
s
.81052 .52568 m
.80685 .52493 L
s
.80047 .25541 m
.79684 .25448 L
s
.79854 .20344 m
.79491 .20248 L
s
.79663 .15214 m
.79301 .15115 L
s
.79475 .10148 m
.79114 .10046 L
s
.81473 .63892 m
.81105 .63824 L
s
.81688 .6967 m
.81319 .69606 L
s
.81906 .75528 m
.81536 .75467 L
s
gsave
.88045 .4535 -61 -9.44655 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.23322 .24553 m
.21183 .8926 L
s
.21183 .8926 m
.50086 .92877 L
s
.50086 .92877 m
.50079 .30775 L
s
.50079 .30775 m
.23322 .24553 L
s
.49903 .0149 m
.79464 .09859 L
s
.79464 .09859 m
.82095 .80615 L
s
.82095 .80615 m
.49894 .75626 L
s
.49894 .75626 m
.49903 .0149 L
s
.23322 .24553 m
.21183 .8926 L
s
.21183 .8926 m
.49894 .75626 L
s
.49894 .75626 m
.49903 .0149 L
s
.49903 .0149 m
.23322 .24553 L
s
.50079 .30775 m
.79464 .09859 L
s
.79464 .09859 m
.82095 .80615 L
s
.82095 .80615 m
.50086 .92877 L
s
.50086 .92877 m
.50079 .30775 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.42194 .78024 m .42631 .2986 L .3756 .28688 L p 0 .35 .745 r
F P
0 g
s
.55311 .204 m .42631 .2986 L .42194 .78024 L p 0 .183 .697 r
F P
0 g
s
.42631 .2986 m .55311 .204 L .5 .19057 L p 0 .435 1 r
F P
0 g
s
.5 .19057 m .3756 .28688 L .42631 .2986 L p 0 .435 1 r
F P
0 g
s
.3756 .28688 m .36816 .77224 L .42194 .78024 L p 0 .35 .745 r
F P
0 g
s
.55649 .71541 m .42194 .78024 L .50081 .79198 L p 0 .455 1 r
F P
0 g
s
.50082 .90949 m .50081 .79198 L .42194 .78024 L p 0 .35 .745 r
F P
0 g
s
.42194 .78024 m .42086 .89921 L .50082 .90949 L p 0 .35 .745 r
F P
0 g
s
.42086 .89921 m .42194 .78024 L .55649 .71541 L p 0 .183 .697 r
F P
0 g
s
.42194 .78024 m .55649 .71541 L .55311 .204 L p 0 .183 .697 r
F P
0 g
s
.63919 .72895 m .50081 .79198 L .50082 .90949 L p 0 .193 .706 r
F P
0 g
s
.50081 .79198 m .63919 .72895 L .55649 .71541 L p 0 .455 1 r
F P
0 g
s
.50082 .90949 m .64123 .85426 L .63919 .72895 L p 0 .193 .706 r
F P
0 g
s
.55649 .71541 m .55733 .84239 L .42086 .89921 L p 0 .183 .697 r
F P
0 g
s
.55649 .71541 m .55311 .204 L .5 .19057 L p 0 .351 .737 r
F P
0 g
s
.5 .19057 m .5 .70617 L .55649 .71541 L p 0 .351 .737 r
F P
0 g
s
.36816 .77224 m .3756 .28688 L .5 .19057 L p 0 .177 .691 r
F P
0 g
s
.31338 .76409 m .36816 .77224 L .3756 .28688 L p 0 .35 .745 r
F P
0 g
s
.3756 .28688 m .324 .27495 L .31338 .76409 L p 0 .35 .745 r
F P
0 g
s
.55649 .71541 m .63919 .72895 L .64123 .85426 L p 0 .351 .737 r
F P
0 g
s
.8042 .79017 m .79946 .65595 L .63919 .72895 L p 0 .193 .706 r
F P
0 g
s
.63919 .72895 m .64123 .85426 L .8042 .79017 L p 0 .193 .706 r
F P
0 g
s
.64123 .85426 m .63919 .72895 L .55649 .71541 L p 0 .351 .737 r
F P
0 g
s
.55649 .71541 m .63919 .72895 L .79946 .65595 L p 0 .455 1 r
F P
0 g
s
.79946 .65595 m .71266 .64017 L .71266 .64017 L p 0 .455 1 r
F P
0 g
s
.71266 .64017 m .55649 .71541 L p .79946 .65595 L 0 .455 1 r
F P
0 g
s
.79946 .65595 m .79946 .65595 L .71266 .64017 L 0 .455 1 r
F
.55649 .71541 m .71266 .64017 L p .55649 .71541 L 0 .183 .697 r
F P
0 g
s
.71266 .64017 m .71608 .7763 L p .55649 .71541 L 0 .183 .697 r
F P
0 g
s
.55311 .204 m .55649 .71541 L .71266 .64017 L p 0 .183 .697 r
F P
0 g
s
.63156 .67924 m .71266 .64017 L .69301 .6366 L p 0 .455 1 r
F P
0 g
s
.69301 .6366 m .71266 .64017 L .71266 .64017 L p 0 .351 .727 r
F P
0 g
s
.71266 .64017 m .69896 .09518 L .55311 .204 L p 0 .183 .697 r
F P
0 g
s
.5 .19057 m .55311 .204 L .55649 .71541 L p 0 .351 .737 r
F P
0 g
s
.55649 .71541 m .5 .70617 L .5 .19057 L p 0 .351 .737 r
F P
0 g
s
.6124 .67594 m .5378 .71235 L .55649 .71541 L p 0 .455 1 r
F P
0 g
s
.55649 .71541 m .63156 .67924 L .6124 .67594 L p 0 .455 1 r
F P
0 g
s
.5378 .71235 m .6124 .67594 L .59308 .67262 L p 0 .455 1 r
F P
0 g
s
.59308 .67262 m .51896 .70927 L .5378 .71235 L p 0 .455 1 r
F P
0 g
s
.51896 .70927 m .59308 .67262 L .57363 .66927 L p 0 .455 1 r
F P
0 g
s
.57363 .66927 m .5 .70617 L .51896 .70927 L p 0 .455 1 r
F P
0 g
s
.5 .70617 m .57363 .66927 L .57363 .66927 L p 0 .177 .691 r
F P
0 g
s
.69301 .6366 m .6124 .67594 L .63156 .67924 L p 0 .455 1 r
F P
0 g
s
.59308 .67262 m .6124 .67594 L .69301 .6366 L p 0 .455 1 r
F P
0 g
s
.71266 .64017 m .55649 .71541 L .5 .70617 L p 0 .455 1 r
F P
0 g
s
.42194 .78024 m .48681 .74899 L .46857 .74615 L p 0 .455 1 r
F P
0 g
s
.46857 .74615 m .40414 .77759 L .42194 .78024 L p 0 .455 1 r
F P
0 g
s
.3862 .77492 m .40414 .77759 L .46857 .74615 L p 0 .455 1 r
F P
0 g
s
.46857 .74615 m .45019 .74328 L .3862 .77492 L p 0 .455 1 r
F P
0 g
s
.48681 .74899 m .55649 .71541 L .5378 .71235 L p 0 .455 1 r
F P
0 g
s
.5378 .71235 m .46857 .74615 L .48681 .74899 L p 0 .455 1 r
F P
0 g
s
.51896 .70927 m .45019 .74328 L .46857 .74615 L p 0 .455 1 r
F P
0 g
s
.46857 .74615 m .5378 .71235 L .51896 .70927 L p 0 .455 1 r
F P
0 g
s
.45019 .74328 m .51896 .70927 L .5 .70617 L p 0 .455 1 r
F P
0 g
s
.5378 .71235 m .55649 .71541 L .55649 .71541 L p 0 .351 .737 r
F P
0 g
s
.55649 .71541 m .42194 .78024 L p .5 .70617 L 0 .455 1 r
F P
0 g
s
.55649 .71541 m .48681 .74899 L .48681 .74902 L p 0 .183 .697 r
F P
0 g
s
.48681 .74902 m .55649 .71544 L .55649 .71541 L p 0 .183 .697 r
F P
0 g
s
.55649 .71541 m .55649 .71544 L p .5378 .71235 L 0 .351 .737 r
F P
0 g
s
.5378 .71235 m .55649 .71541 L .5378 .71235 L 0 .351 .737 r
F
.55677 .75731 m .55649 .71544 L .48681 .74902 L p 0 .183 .697 r
F P
0 g
s
.51896 .70927 m .5378 .71235 L .53987 .73142 L p 0 .351 .737 r
F P
0 g
s
.5 .70617 m .55649 .71541 L .55649 .71541 L p 0 .455 1 r
F P
0 g
s
.48681 .74902 m .48674 .78954 L .55677 .75731 L p 0 .183 .697 r
F P
0 g
s
.50606 .76394 m .5 .70617 L .51896 .70927 L p 0 .351 .737 r
F P
0 g
s
.5 .70617 m .55649 .71541 L .5 .70617 L 0 .455 1 r
F
.45019 .74328 m .43169 .7404 L .36816 .77224 L p F P
0 g
s
.36816 .77224 m .43169 .7404 L .43169 .7404 L p 0 .177 .691 r
F P
0 g
s
.48681 .74899 m .42194 .78024 L .42194 .78027 L p 0 .183 .697 r
F P
0 g
s
.42194 .78024 m .40414 .77759 L .40583 .79545 L p 0 .35 .745 r
F P
0 g
s
.40583 .79545 m .42194 .78027 L .42194 .78024 L p 0 .35 .745 r
F P
0 g
s
.36816 .77224 m .3862 .77492 L .45019 .74328 L p 0 .455 1 r
F P
0 g
s
.5 .70617 m .43169 .7404 L .45019 .74328 L p 0 .455 1 r
F P
0 g
s
.43169 .7404 m .5 .70617 L .5 .70617 L p 0 .177 .691 r
F P
0 g
s
.43169 .7404 m .43169 .7404 L .5 .70617 L 0 .177 .691 r
F
.36816 .77224 m .36816 .77224 L .43169 .7404 L F
.5 .19057 m .5 .70617 L .36816 .77224 L p F P
0 g
s
.5 .70617 m .57363 .66927 L .5 .70617 L 0 .177 .691 r
F
.64123 .85426 m .55733 .84239 L .55649 .71541 L p 0 .351 .737 r
F P
0 g
s
.55649 .71541 m .55733 .84239 L .64123 .85426 L p 0 .351 .737 r
F P
0 g
s
.71608 .7763 m .55733 .84239 L .55649 .71541 L p 0 .183 .697 r
F P
0 g
s
.63156 .67924 m .55649 .71541 L .55649 .71544 L p 0 .183 .697 r
F P
0 g
s
.55649 .71544 m .63156 .67927 L .63156 .67924 L p 0 .183 .697 r
F P
0 g
s
.63223 .72258 m .63156 .67927 L .55649 .71544 L p 0 .183 .697 r
F P
0 g
s
.6732 .633 m .65324 .62938 L .57363 .66927 L p 0 .455 1 r
F P
0 g
s
.57363 .66927 m .65324 .62938 L .65324 .62938 L p 0 .177 .691 r
F P
0 g
s
.57363 .66927 m .59308 .67262 L .6732 .633 L p 0 .455 1 r
F P
0 g
s
.69301 .6366 m .6732 .633 L .59308 .67262 L p 0 .455 1 r
F P
0 g
s
.5 .70617 m .65324 .62938 L p .71266 .64017 L 0 .455 1 r
F P
0 g
s
.71266 .64017 m .63156 .67924 L .63156 .67927 L p 0 .183 .697 r
F P
0 g
s
.63156 .67927 m .71266 .6402 L .71266 .64017 L p 0 .183 .697 r
F P
0 g
s
.71266 .6402 m .63156 .67927 L .63223 .72258 L p 0 .183 .697 r
F P
0 g
s
.6732 .633 m .69301 .6366 L .69555 .65706 L p 0 .351 .727 r
F P
0 g
s
.65324 .62938 m .71266 .64017 L p .71266 .64017 L 0 .455 1 r
F P
0 g
s
.65324 .62938 m .6732 .633 L .67824 .67413 L p 0 .351 .727 r
F P
0 g
s
.65324 .62938 m .65324 .62938 L p .71266 .64017 L 0 .455 1 r
F P
0 g
s
.71266 .6402 m .69555 .65706 L .69301 .6366 L p 0 .351 .727 r
F P
0 g
s
.65324 .62938 m .65448 .69755 L p .57363 .66927 L 0 .177 .691 r
F P
0 g
s
.57363 .66927 m .65324 .62938 L .57363 .66927 L 0 .177 .691 r
F
.65324 .62938 m .5 .70617 L .5 .19057 L p F P
0 g
s
.5 .19057 m .5 .70617 L .65324 .62938 L p 0 .177 .691 r
F P
0 g
s
.63315 .62572 m .61291 .62205 L .53433 .6625 L p 0 .455 1 r
F P
0 g
s
.5 .70617 m .57363 .66927 L .55405 .6659 L p 0 .455 1 r
F P
0 g
s
.5 .70617 m .5 .70617 L .5 .19057 L p 0 .177 .691 r
F P
0 g
s
.5 .19057 m .55311 .204 L .69896 .09518 L p 0 .435 1 r
F P
0 g
s
.69896 .09518 m .64328 .07965 L .5 .19057 L p 0 .435 1 r
F P
0 g
s
.5 .19057 m .64328 .07965 L .65324 .62938 L p 0 .177 .691 r
F P
0 g
s
.36816 .77224 m .5 .70617 L p .5 .19057 L 0 .177 .691 r
F P
0 g
s
.43169 .7404 m .5 .70617 L .48091 .70305 L p 0 .455 1 r
F P
0 g
s
.48091 .70305 m .5 .70617 L p .5 .70617 L 0 .351 .737 r
F P
0 g
s
.48091 .70305 m .48091 .70305 L p .5 .70617 L 0 .351 .737 r
F P
0 g
s
.5 .19057 m .3756 .28688 L .36816 .77224 L p 0 .177 .691 r
F P
0 g
s
.44238 .69674 m .5 .70617 L .5 .19057 L p 0 .351 .737 r
F P
0 g
s
.65324 .62938 m .64328 .07965 L .5 .19057 L p 0 .177 .691 r
F P
0 g
s
.5 .19057 m .5 .70617 L .44238 .69674 L p 0 .351 .737 r
F P
0 g
s
.55405 .6659 m .48091 .70305 L .5 .70617 L p 0 .455 1 r
F P
0 g
s
.48091 .70305 m .55405 .6659 L .53433 .6625 L p 0 .455 1 r
F P
0 g
s
.55405 .6659 m .57363 .66927 L .65324 .62938 L p 0 .455 1 r
F P
0 g
s
.65324 .62938 m .63315 .62572 L .55405 .6659 L p 0 .455 1 r
F P
0 g
s
.53433 .6625 m .55405 .6659 L .63315 .62572 L p 0 .455 1 r
F P
0 g
s
.53433 .6625 m .61291 .62205 L .59255 .61835 L p 0 .455 1 r
F P
0 g
s
.65324 .62938 m .5 .70617 L p .59255 .61835 L 0 .455 1 r
F P
0 g
s
.59255 .61835 m .51451 .65909 L .53433 .6625 L p 0 .455 1 r
F P
0 g
s
.51451 .65909 m .59255 .61835 L .59255 .61835 L p 0 .169 .684 r
F P
0 g
s
.53433 .6625 m .4617 .6999 L .48091 .70305 L p 0 .455 1 r
F P
0 g
s
.51451 .65909 m .44238 .69674 L .4617 .6999 L p 0 .455 1 r
F P
0 g
s
.4617 .6999 m .53433 .6625 L .51451 .65909 L p 0 .455 1 r
F P
0 g
s
.51451 .65909 m .51451 .65909 L .59255 .61835 L 0 .169 .684 r
F
.44238 .69674 m .59255 .61835 L p .59255 .61835 L 0 .455 1 r
F P
0 g
s
.5 .70617 m .44238 .69674 L p .59255 .61835 L 0 .455 1 r
F P
0 g
s
.44238 .69674 m .44238 .69674 L p .59255 .61835 L 0 .455 1 r
F P
0 g
s
.44238 .69674 m .51451 .65909 L .51451 .65909 L p 0 .169 .684 r
F P
0 g
s
.51451 .65909 m .51451 .65912 L p .44238 .69674 L 0 .169 .684 r
F P
0 g
s
.44238 .69674 m .44238 .69674 L .51451 .65909 L 0 .169 .684 r
F
.59255 .61835 m .59255 .61838 L p .51451 .65909 L F P
0 g
s
.42194 .78024 m .36816 .77224 L .5 .70617 L p 0 .455 1 r
F P
0 g
s
.42194 .78027 m .48681 .74902 L .48681 .74899 L p 0 .183 .697 r
F P
0 g
s
.48681 .74902 m .42194 .78027 L .42158 .81952 L p 0 .183 .697 r
F P
0 g
s
.42158 .81952 m .48674 .78954 L .48681 .74902 L p 0 .183 .697 r
F P
0 g
s
.5 .70617 m .5 .76976 L p .43169 .7404 L 0 .177 .691 r
F P
0 g
s
.35 .76954 m .36816 .77224 L .43169 .7404 L p 0 .455 1 r
F P
0 g
s
.43169 .7404 m .41308 .7375 L .35 .76954 L p 0 .455 1 r
F P
0 g
s
.33173 .76682 m .35 .76954 L .41308 .7375 L p 0 .455 1 r
F P
0 g
s
.41308 .7375 m .39435 .73458 L .33173 .76682 L p 0 .455 1 r
F P
0 g
s
.33173 .76682 m .39435 .73458 L .37552 .73164 L p 0 .455 1 r
F P
0 g
s
.37552 .73164 m .31338 .76409 L .33173 .76682 L p 0 .455 1 r
F P
0 g
s
.48091 .70305 m .41308 .7375 L .43169 .7404 L p 0 .455 1 r
F P
0 g
s
.4617 .6999 m .39435 .73458 L .41308 .7375 L p 0 .455 1 r
F P
0 g
s
.41308 .7375 m .48091 .70305 L .4617 .6999 L p 0 .455 1 r
F P
0 g
s
.5 .70617 m .36816 .77224 L .31338 .76409 L p 0 .455 1 r
F P
0 g
s
.33173 .76682 m .31338 .76409 L .31337 .76411 L p 0 .35 .745 r
F P
0 g
s
.44238 .69674 m .37552 .73164 L .39435 .73458 L p 0 .455 1 r
F P
0 g
s
.39435 .73458 m .4617 .6999 L .44238 .69674 L p 0 .455 1 r
F P
0 g
s
.44238 .69674 m .5 .70617 L p .5 .70617 L 0 .455 1 r
F P
0 g
s
.5 .70617 m .31338 .76409 L .44238 .69674 L 0 .455 1 r
F
.44238 .69674 m .4617 .6999 L .45957 .71855 L p 0 .351 .737 r
F P
0 g
s
.5 .70617 m .44238 .69674 L .44238 .69674 L 0 .455 1 r
F
.4617 .6999 m .48091 .70305 L .48091 .70305 L p 0 .351 .737 r
F P
0 g
s
.5 .76976 m .4312 .80192 L .43169 .7404 L p 0 .177 .691 r
F P
0 g
s
.5 .70617 m .43169 .7404 L .4312 .80192 L p 0 .177 .691 r
F P
0 g
s
.4312 .80192 m .5 .76976 L .5 .70617 L p 0 .177 .691 r
F P
0 g
s
.48091 .70305 m .47676 .74033 L p .4617 .6999 L 0 .351 .737 r
F P
0 g
s
.4617 .6999 m .4617 .6999 L .48091 .70305 L 0 .351 .737 r
F
.37552 .73164 m .44238 .69674 L .44238 .69677 L p 0 .169 .684 r
F P
0 g
s
.31338 .76409 m .44238 .69674 L .44238 .69674 L p 0 .455 1 r
F P
0 g
s
.31338 .76409 m .31338 .76409 L .44238 .69674 L 0 .455 1 r
F
.31338 .76409 m .37552 .73164 L .37552 .73164 L p 0 .169 .684 r
F P
0 g
s
.37552 .73164 m .37552 .73167 L p .31338 .76409 L 0 .169 .684 r
F P
0 g
s
.31338 .76409 m .37552 .73164 L .31338 .76409 L 0 .169 .684 r
F
.37552 .73167 m .31337 .76411 L .31338 .76409 L p F P
0 g
s
.40583 .79545 m .42158 .81952 L .42194 .78027 L closepath p 0 .35 .745 r
F P
0 g
s
.40414 .77759 m .3862 .77492 L .38954 .8108 L p 0 .35 .745 r
F P
0 g
s
.38954 .8108 m .40583 .79545 L .40414 .77759 L p 0 .35 .745 r
F P
0 g
s
.3862 .77492 m .36816 .77224 L .3731 .8263 L p 0 .35 .745 r
F P
0 g
s
.3731 .8263 m .38954 .8108 L .3862 .77492 L p 0 .35 .745 r
F P
0 g
s
.43169 .7404 m .4312 .80192 L p .36816 .77224 L 0 .177 .691 r
F P
0 g
s
.34552 .80451 m .36157 .82469 L .36816 .77224 L p 0 .35 .745 r
F P
0 g
s
.36816 .77224 m .35 .76954 L .34552 .80451 L p 0 .35 .745 r
F P
0 g
s
.42122 .8592 m .42158 .81952 L .40583 .79545 L p 0 .35 .745 r
F P
0 g
s
.40583 .79545 m .38954 .8108 L .42122 .8592 L p 0 .35 .745 r
F P
0 g
s
.36724 .83182 m .3731 .8263 L .36816 .77224 L closepath p 0 .35 .745 r
F P
0 g
s
.42086 .89921 m .42122 .8592 L .38954 .8108 L p 0 .35 .745 r
F P
0 g
s
.42085 .89921 m .42086 .89921 L p .38954 .8108 L 0 .35 .745 r
F P
0 g
s
.38954 .8108 m .3731 .8263 L .42085 .89921 L p 0 .35 .745 r
F P
0 g
s
.39154 .89545 m .42085 .89921 L .3731 .8263 L p 0 .35 .745 r
F P
0 g
s
.36684 .85774 m .39154 .89545 L p .3731 .8263 L 0 .35 .745 r
F P
0 g
s
.3731 .8263 m .36724 .83182 L .36684 .85774 L p 0 .35 .745 r
F P
0 g
s
.4312 .80192 m .36724 .83182 L .36816 .77224 L p 0 .177 .691 r
F P
0 g
s
.43169 .7404 m .36816 .77224 L .36724 .83182 L p 0 .177 .691 r
F P
0 g
s
.36816 .77224 m .36157 .82469 L .36724 .83182 L closepath p 0 .35 .745 r
F P
0 g
s
.36157 .82469 m .34552 .80451 L .31163 .84436 L p 0 .35 .745 r
F P
0 g
s
.324 .27495 m .3756 .28688 L .5 .19057 L p 0 .435 1 r
F P
0 g
s
.5 .19057 m .4459 .1769 L .324 .27495 L p 0 .435 1 r
F P
0 g
s
.5 .19057 m .4459 .1769 L .44238 .69674 L p 0 .351 .737 r
F P
0 g
s
.31338 .76409 m .324 .27495 L .4459 .1769 L p 0 .169 .684 r
F P
0 g
s
.32944 .78431 m .34552 .80451 L .35 .76954 L p 0 .35 .745 r
F P
0 g
s
.35 .76954 m .33173 .76682 L .32944 .78431 L p 0 .35 .745 r
F P
0 g
s
.31337 .76411 m .32944 .78431 L .33173 .76682 L p 0 .35 .745 r
F P
0 g
s
.31076 .88507 m .36157 .82469 L p .31163 .84436 L 0 .35 .745 r
F P
0 g
s
.34552 .80451 m .32944 .78431 L .31251 .80402 L p 0 .35 .745 r
F P
0 g
s
.31251 .80402 m .31163 .84436 L .34552 .80451 L p 0 .35 .745 r
F P
0 g
s
.31337 .76411 m .31251 .80402 L .32944 .78431 L closepath p 0 .35 .745 r
F P
0 g
s
.4459 .1769 m .44238 .69674 L .31338 .76409 L p 0 .169 .684 r
F P
0 g
s
.31337 .76411 m .37552 .73167 L .37492 .77289 L p 0 .169 .684 r
F P
0 g
s
.37492 .77289 m .31251 .80402 L .31337 .76411 L p 0 .169 .684 r
F P
0 g
s
.31251 .80402 m .37492 .77289 L .37432 .81457 L p 0 .169 .684 r
F P
0 g
s
.37432 .81457 m .31163 .84436 L .31251 .80402 L p 0 .169 .684 r
F P
0 g
s
.36684 .85774 m .36724 .83182 L .4312 .80192 L p 0 .177 .691 r
F P
0 g
s
.36724 .83182 m .4312 .80192 L .43169 .7404 L p 0 .177 .691 r
F P
0 g
s
.48674 .78954 m .42158 .81952 L .42122 .8592 L p 0 .183 .697 r
F P
0 g
s
.4312 .80192 m .43099 .8287 L .36684 .85774 L p 0 .177 .691 r
F P
0 g
s
.43099 .8287 m .4312 .80192 L .36724 .83182 L p 0 .177 .691 r
F P
0 g
s
.36724 .83182 m .36684 .85774 L .43099 .8287 L p 0 .177 .691 r
F P
0 g
s
.36724 .83182 m .36157 .82469 L .31076 .88507 L p 0 .35 .745 r
F P
0 g
s
.36684 .85774 m .36724 .83182 L p .31076 .88507 L 0 .35 .745 r
F P
0 g
s
.36684 .85774 m .36632 .8922 L .39154 .89545 L closepath p 0 .35 .745 r
F P
0 g
s
.36632 .8922 m .36684 .85774 L .43099 .8287 L p 0 .177 .691 r
F P
0 g
s
.48668 .8305 m .42122 .8592 L .42086 .89921 L p 0 .183 .697 r
F P
0 g
s
.42122 .8592 m .48668 .8305 L .48674 .78954 L p 0 .183 .697 r
F P
0 g
s
.43099 .8287 m .4307 .86431 L .36632 .8922 L p 0 .177 .691 r
F P
0 g
s
.4307 .86431 m .43099 .8287 L .36684 .85774 L p 0 .177 .691 r
F P
0 g
s
.31163 .84436 m .37432 .81457 L .3737 .85663 L p 0 .169 .684 r
F P
0 g
s
.36684 .85774 m .36632 .8922 L .4307 .86431 L p 0 .177 .691 r
F P
0 g
s
.34087 .88894 m .36632 .8922 L .36684 .85774 L closepath p 0 .35 .745 r
F P
0 g
s
.31076 .88507 m .34087 .88894 L .36684 .85774 L p 0 .35 .745 r
F P
0 g
s
.31163 .84436 m .31075 .88506 L .31076 .88507 L p 0 .35 .745 r
F P
0 g
s
.3737 .85663 m .31075 .88506 L .31163 .84436 L p 0 .169 .684 r
F P
0 g
s
.44238 .69677 m .37552 .73167 L .37552 .73164 L p 0 .169 .684 r
F P
0 g
s
.37492 .77289 m .37552 .73167 L .44238 .69677 L p 0 .169 .684 r
F P
0 g
s
.37432 .81457 m .37492 .77289 L .44209 .73938 L p 0 .169 .684 r
F P
0 g
s
.44238 .69677 m .44209 .73938 L .37492 .77289 L p 0 .169 .684 r
F P
0 g
s
.44238 .69674 m .31338 .76409 L .31075 .88506 L p 0 .169 .684 r
F P
0 g
s
.22928 .75157 m .31338 .76409 L .44238 .69674 L p 0 .455 1 r
F P
0 g
s
.44238 .69674 m .35377 .68224 L .22928 .75157 L p 0 .455 1 r
F P
0 g
s
.35151 .81327 m .35377 .68224 L .44218 .69671 L p 0 .351 .737 r
F P
0 g
s
.47676 .74033 m .48091 .70305 L p .5 .70617 L 0 .351 .737 r
F P
0 g
s
.55649 .71544 m .53987 .73142 L .5378 .71235 L p 0 .351 .737 r
F P
0 g
s
.55649 .71541 m .5378 .71235 L .53987 .73142 L p 0 .351 .737 r
F P
0 g
s
.53987 .73142 m .55649 .71544 L .55649 .71541 L p 0 .351 .737 r
F P
0 g
s
.53987 .73142 m .55649 .71544 L .55677 .75731 L closepath p 0 .351 .737 r
F P
0 g
s
.55649 .71544 m .55677 .75731 L .63223 .72258 L p 0 .183 .697 r
F P
0 g
s
.55677 .75731 m .55649 .71544 L .53987 .73142 L closepath p 0 .351 .737 r
F P
0 g
s
.53987 .73142 m .52305 .7476 L .51896 .70927 L p 0 .351 .737 r
F P
0 g
s
.5378 .71235 m .51896 .70927 L .52305 .7476 L p 0 .351 .737 r
F P
0 g
s
.52305 .7476 m .53987 .73142 L .5378 .71235 L p 0 .351 .737 r
F P
0 g
s
.51896 .70927 m .52305 .7476 L .50606 .76394 L p 0 .351 .737 r
F P
0 g
s
.52305 .7476 m .51896 .70927 L .5 .70617 L p 0 .351 .737 r
F P
0 g
s
.57363 .66927 m .5742 .73507 L p .5 .70617 L 0 .177 .691 r
F P
0 g
s
.44238 .69674 m .4459 .1769 L .5 .19057 L p 0 .351 .737 r
F P
0 g
s
.59255 .61835 m .44238 .69674 L .4459 .1769 L p 0 .169 .684 r
F P
0 g
s
.5 .70617 m .49393 .76207 L .47676 .74033 L p 0 .351 .737 r
F P
0 g
s
.55705 .79965 m .55677 .75731 L .48674 .78954 L p 0 .183 .697 r
F P
0 g
s
.55677 .75731 m .55705 .79965 L .52305 .7476 L p 0 .351 .737 r
F P
0 g
s
.52305 .7476 m .53987 .73142 L .55677 .75731 L p 0 .351 .737 r
F P
0 g
s
.55705 .79965 m .55677 .75731 L .53987 .73142 L p 0 .351 .737 r
F P
0 g
s
.53987 .73142 m .52305 .7476 L .55705 .79965 L p 0 .351 .737 r
F P
0 g
s
.5 .70617 m .50606 .76394 L .52305 .7476 L p 0 .351 .737 r
F P
0 g
s
.50606 .76394 m .5 .76976 L .5 .70617 L closepath p 0 .351 .737 r
F P
0 g
s
.5 .70617 m .5 .76976 L .50606 .76394 L closepath p 0 .351 .737 r
F P
0 g
s
.48674 .78954 m .48668 .8305 L .55705 .79965 L p 0 .183 .697 r
F P
0 g
s
.55733 .84239 m .55705 .79965 L .48668 .8305 L p 0 .183 .697 r
F P
0 g
s
.55705 .79965 m .55733 .84239 L p .50606 .76394 L 0 .351 .737 r
F P
0 g
s
.50606 .76394 m .52305 .7476 L .55705 .79965 L p 0 .351 .737 r
F P
0 g
s
.48668 .8305 m .48662 .87184 L .55733 .84239 L p 0 .183 .697 r
F P
0 g
s
.55733 .84239 m .55732 .84239 L .50606 .76394 L p 0 .351 .737 r
F P
0 g
s
.55705 .79965 m .52305 .7476 L p .55732 .84239 L 0 .351 .737 r
F P
0 g
s
.52305 .7476 m .50606 .76394 L .55732 .84239 L p 0 .351 .737 r
F P
0 g
s
.50606 .76394 m .55732 .84239 L .52653 .83803 L p 0 .351 .737 r
F P
0 g
s
.5 .79745 m .5 .76976 L .50606 .76394 L p 0 .351 .737 r
F P
0 g
s
.52653 .83803 m .5 .79745 L p .50606 .76394 L 0 .351 .737 r
F P
0 g
s
.55732 .84239 m .50606 .76394 L .5 .76976 L p 0 .351 .737 r
F P
0 g
s
.5742 .73507 m .5 .76976 L .5 .70617 L p 0 .177 .691 r
F P
0 g
s
.57363 .66927 m .5 .70617 L .5 .76976 L p 0 .177 .691 r
F P
0 g
s
.49393 .76207 m .5 .70617 L .48091 .70305 L p 0 .351 .737 r
F P
0 g
s
.5 .70617 m .5 .76976 L .49393 .76207 L closepath p 0 .351 .737 r
F P
0 g
s
.49393 .76207 m .5 .76976 L .5 .70617 L closepath p 0 .351 .737 r
F P
0 g
s
.45957 .71855 m .44238 .69677 L .44238 .69674 L p 0 .351 .737 r
F P
0 g
s
.4617 .6999 m .44238 .69674 L .44238 .69677 L p 0 .351 .737 r
F P
0 g
s
.51451 .65912 m .44238 .69677 L .44238 .69674 L p 0 .169 .684 r
F P
0 g
s
.63291 .7664 m .63223 .72258 L .55677 .75731 L p 0 .183 .697 r
F P
0 g
s
.48091 .70305 m .47676 .74033 L .49393 .76207 L p 0 .351 .737 r
F P
0 g
s
.47676 .74033 m .45957 .71855 L .4617 .6999 L p 0 .351 .737 r
F P
0 g
s
.45957 .71855 m .47676 .74033 L .48091 .70305 L p 0 .351 .737 r
F P
0 g
s
.48091 .70305 m .4617 .6999 L .45957 .71855 L p 0 .351 .737 r
F P
0 g
s
.44238 .69677 m .45957 .71855 L .4617 .6999 L p 0 .351 .737 r
F P
0 g
s
.55677 .75731 m .55705 .79965 L .63291 .7664 L p 0 .183 .697 r
F P
0 g
s
.5 .76976 m .5742 .73507 L .57445 .76374 L p 0 .177 .691 r
F P
0 g
s
.5 .76976 m .5742 .73507 L .57363 .66927 L p 0 .177 .691 r
F P
0 g
s
.52653 .83803 m .55732 .84239 L p .5 .76976 L 0 .351 .737 r
F P
0 g
s
.5 .76976 m .5 .79745 L .52653 .83803 L p 0 .351 .737 r
F P
0 g
s
.57445 .76374 m .5 .79745 L .5 .76976 L p 0 .177 .691 r
F P
0 g
s
.5742 .73507 m .5 .76976 L .5 .79745 L p 0 .177 .691 r
F P
0 g
s
.45957 .71855 m .47676 .74033 L .4418 .78249 L p 0 .351 .737 r
F P
0 g
s
.4418 .78249 m .44209 .73938 L .45957 .71855 L p 0 .351 .737 r
F P
0 g
s
.47676 .74033 m .45957 .71855 L .44209 .73938 L p 0 .351 .737 r
F P
0 g
s
.44209 .73938 m .44238 .69677 L .45957 .71855 L closepath p 0 .351 .737 r
F P
0 g
s
.45957 .71855 m .44238 .69677 L .44209 .73938 L closepath p 0 .351 .737 r
F P
0 g
s
.44209 .73938 m .44238 .69677 L .51451 .65912 L p 0 .169 .684 r
F P
0 g
s
.5 .79745 m .57445 .76374 L .5742 .73507 L p 0 .177 .691 r
F P
0 g
s
.5 .79745 m .43099 .8287 L .4312 .80192 L p 0 .177 .691 r
F P
0 g
s
.4312 .80192 m .5 .76976 L .5 .79745 L p 0 .177 .691 r
F P
0 g
s
.5 .76976 m .4312 .80192 L .43099 .8287 L p 0 .177 .691 r
F P
0 g
s
.42086 .89921 m .48662 .87184 L .48668 .8305 L p 0 .183 .697 r
F P
0 g
s
.43099 .8287 m .5 .79745 L .5 .83428 L p 0 .177 .691 r
F P
0 g
s
.5 .83428 m .4307 .86431 L .43099 .8287 L p 0 .177 .691 r
F P
0 g
s
.5 .79745 m .43099 .8287 L .4307 .86431 L p 0 .177 .691 r
F P
0 g
s
.43099 .8287 m .5 .79745 L .5 .76976 L p 0 .177 .691 r
F P
0 g
s
.47676 .74033 m .49393 .76207 L .44152 .82601 L p 0 .351 .737 r
F P
0 g
s
.4418 .78249 m .47676 .74033 L p .44152 .82601 L 0 .351 .737 r
F P
0 g
s
.49393 .76207 m .47676 .74033 L .4418 .78249 L p 0 .351 .737 r
F P
0 g
s
.44209 .73938 m .4418 .78249 L .47676 .74033 L p 0 .351 .737 r
F P
0 g
s
.4418 .78249 m .44209 .73938 L .51458 .70322 L p 0 .169 .684 r
F P
0 g
s
.51451 .65912 m .51458 .70322 L .44209 .73938 L p 0 .169 .684 r
F P
0 g
s
.51458 .70322 m .51466 .74785 L .4418 .78249 L p 0 .169 .684 r
F P
0 g
s
.65448 .69755 m .5742 .73507 L .57363 .66927 L p 0 .177 .691 r
F P
0 g
s
.65324 .62938 m .57363 .66927 L .5742 .73507 L p 0 .177 .691 r
F P
0 g
s
.57445 .76374 m .5742 .73507 L .65448 .69755 L p 0 .177 .691 r
F P
0 g
s
.5742 .73507 m .65448 .69755 L .65324 .62938 L p 0 .177 .691 r
F P
0 g
s
.71378 .68505 m .63223 .72258 L .63291 .7664 L p 0 .183 .697 r
F P
0 g
s
.63223 .72258 m .71378 .68505 L .71266 .6402 L p 0 .183 .697 r
F P
0 g
s
.65448 .69755 m .65502 .72726 L .57445 .76374 L p 0 .177 .691 r
F P
0 g
s
.65502 .72726 m .65448 .69755 L .5742 .73507 L p 0 .177 .691 r
F P
0 g
s
.5742 .73507 m .57445 .76374 L .65502 .72726 L p 0 .177 .691 r
F P
0 g
s
.59255 .61838 m .51451 .65912 L .51451 .65909 L p 0 .169 .684 r
F P
0 g
s
.59305 .66408 m .51458 .70322 L .51451 .65912 L p 0 .169 .684 r
F P
0 g
s
.51451 .65912 m .59255 .61838 L .59305 .66408 L p 0 .169 .684 r
F P
0 g
s
.63359 .81064 m .63291 .7664 L .55705 .79965 L p 0 .183 .697 r
F P
0 g
s
.57478 .80188 m .57445 .76374 L .65502 .72726 L p 0 .177 .691 r
F P
0 g
s
.71492 .73044 m .63291 .7664 L .63359 .81064 L p 0 .183 .697 r
F P
0 g
s
.63291 .7664 m .71492 .73044 L .71378 .68505 L p 0 .183 .697 r
F P
0 g
s
.65502 .72726 m .65573 .7668 L .57478 .80188 L p 0 .177 .691 r
F P
0 g
s
.65573 .7668 m .65502 .72726 L .57445 .76374 L p 0 .177 .691 r
F P
0 g
s
.59356 .71035 m .51466 .74785 L .51458 .70322 L p 0 .169 .684 r
F P
0 g
s
.51458 .70322 m .59305 .66408 L .59356 .71035 L p 0 .169 .684 r
F P
0 g
s
.51466 .74785 m .59356 .71035 L .59407 .7571 L p 0 .169 .684 r
F P
0 g
s
.59407 .7571 m .59255 .61835 L .44238 .69674 L p 0 .169 .684 r
F P
0 g
s
.4307 .86431 m .5 .83428 L .5 .79745 L p 0 .177 .691 r
F P
0 g
s
.44152 .82601 m .49393 .76207 L .5 .76976 L p 0 .351 .737 r
F P
0 g
s
.47323 .83049 m .44152 .82601 L p .5 .76976 L 0 .351 .737 r
F P
0 g
s
.5 .76976 m .5 .79745 L .47323 .83049 L p 0 .351 .737 r
F P
0 g
s
.5 .79745 m .5 .76976 L .49393 .76207 L p 0 .351 .737 r
F P
0 g
s
.47323 .83049 m .5 .79745 L p .49393 .76207 L 0 .351 .737 r
F P
0 g
s
.49393 .76207 m .44152 .82601 L .47323 .83049 L p 0 .351 .737 r
F P
0 g
s
.44152 .82601 m .44151 .82601 L .4418 .78249 L p 0 .351 .737 r
F P
0 g
s
.44151 .82601 m .44152 .82601 L .49393 .76207 L p 0 .351 .737 r
F P
0 g
s
.4418 .78249 m .44151 .82601 L p .49393 .76207 L 0 .351 .737 r
F P
0 g
s
.52653 .83803 m .5 .83428 L .5 .79745 L closepath p 0 .351 .737 r
F P
0 g
s
.5 .79745 m .5 .83428 L .52653 .83803 L closepath p 0 .351 .737 r
F P
0 g
s
.5 .79745 m .5 .83428 L .47323 .83049 L closepath p 0 .351 .737 r
F P
0 g
s
.55705 .79965 m .55733 .84239 L .63359 .81064 L p 0 .183 .697 r
F P
0 g
s
.55732 .84239 m .55733 .84239 L .55705 .79965 L p 0 .351 .737 r
F P
0 g
s
.5 .79745 m .57445 .76374 L .57478 .80188 L p 0 .177 .691 r
F P
0 g
s
.57478 .80188 m .5 .83428 L .5 .79745 L p 0 .177 .691 r
F P
0 g
s
.57445 .76374 m .5 .79745 L .5 .83428 L p 0 .177 .691 r
F P
0 g
s
.47323 .83049 m .5 .83428 L .5 .79745 L closepath p 0 .351 .737 r
F P
0 g
s
.5 .83428 m .57478 .80188 L .57445 .76374 L p 0 .177 .691 r
F P
0 g
s
.44151 .82601 m .4418 .78249 L .51466 .74785 L p 0 .169 .684 r
F P
0 g
s
.51466 .74785 m .51474 .79293 L .44151 .82601 L p 0 .169 .684 r
F P
0 g
s
.57445 .76374 m .57478 .80188 L .65573 .7668 L p 0 .177 .691 r
F P
0 g
s
.59407 .7571 m .51474 .79293 L .51466 .74785 L p 0 .169 .684 r
F P
0 g
s
.44238 .69674 m .44151 .82601 L .59407 .7571 L p 0 .169 .684 r
F P
0 g
s
.44238 .69674 m .59255 .61835 L .49902 .60135 L p 0 .455 1 r
F P
0 g
s
.499 .74214 m .49902 .60135 L .59237 .61831 L p 0 .351 .727 r
F P
0 g
s
.61291 .62205 m .63315 .62572 L .62951 .66563 L p 0 .351 .727 r
F P
0 g
s
.59255 .61835 m .65324 .62938 L .65324 .62938 L p 0 .455 1 r
F P
0 g
s
.59255 .61835 m .61291 .62205 L .61103 .642 L p 0 .351 .727 r
F P
0 g
s
.59255 .61835 m .59255 .61835 L .65324 .62938 L 0 .455 1 r
F
.63315 .62572 m .65324 .62938 L .65324 .62938 L p 0 .351 .727 r
F P
0 g
s
.65324 .62938 m .64796 .68921 L p .63315 .62572 L 0 .351 .727 r
F P
0 g
s
.63315 .62572 m .63315 .62572 L .65324 .62938 L 0 .351 .727 r
F
.71266 .64017 m .71266 .64017 L p .69301 .6366 L F P
0 g
s
.71266 .64017 m .71266 .6402 L p .69301 .6366 L 0 .351 .727 r
F P
0 g
s
.69301 .6366 m .71266 .64017 L .69301 .6366 L 0 .351 .727 r
F
.69301 .6366 m .71266 .64017 L .69301 .6366 L F
0 0 0 r
.3206 .43169 m
.3206 .43169 L
s
.3206 .43169 m
.3206 .43169 L
s
.44477 .34298 m
.44477 .34298 L
s
.44477 .34298 m
.44477 .34298 L
s
.3206 .43169 m
.44477 .34298 L
s
.3206 .43169 m
.3206 .43169 L
s
.38286 .22761 m
.38286 .22761 L
s
.38286 .22761 m
.38286 .22761 L
s
.31706 .59461 m
.31706 .59461 L
s
.31706 .59461 m
.31706 .59461 L
s
.37619 .68591 m
.38286 .22761 L
s
.38286 .22761 m
.38286 .22761 L
s
.4436 .51611 m
.4436 .51611 L
s
.4436 .51611 m
.4436 .51611 L
s
.31706 .59461 m
.4436 .51611 L
s
.31706 .59461 m
.31706 .59461 L
s
.50082 .90949 m .42086 .89921 L .55733 .84239 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.46111 .90439 m
.46111 .90439 L
s
.46111 .90439 m
.46111 .90439 L
s
.55733 .84239 m .64123 .85426 L .50082 .90949 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.46111 .90439 m
.46111 .90439 L
s
.42086 .89921 m .42085 .89921 L .4866 .87183 L p 0 .458 1 r
F P
0 g
s
.4866 .87183 m .48662 .87184 L .42086 .89921 L p 0 .458 1 r
F P
0 g
s
.42085 .89921 m .39154 .89545 L .45657 .86779 L p 0 .458 1 r
F P
0 g
s
.45657 .86779 m .4866 .87183 L .42085 .89921 L p 0 .458 1 r
F P
0 g
s
.22541 .8741 m .31075 .88506 L .31338 .76409 L p 0 .35 .745 r
F P
0 g
s
.31338 .76409 m .22928 .75157 L .22541 .8741 L p 0 .35 .745 r
F P
0 g
s
.45657 .86779 m .39154 .89545 L .36632 .8922 L p 0 .458 1 r
F P
0 g
s
.58647 .06381 m .4459 .1769 L .5 .19057 L p 0 .435 1 r
F P
0 g
s
.5 .19057 m .64328 .07965 L .58647 .06381 L p 0 .435 1 r
F P
0 g
s
0 0 0 r
.56851 .88286 m
.56851 .88286 L
s
.56851 .88286 m
.56851 .88286 L
s
.36632 .8922 m .4307 .86431 L .45657 .86779 L p 0 .458 1 r
F P
0 g
s
.4307 .86431 m .36632 .8922 L .34087 .88894 L p 0 .458 1 r
F P
0 g
s
.34087 .88894 m .40461 .86079 L .4307 .86431 L p 0 .458 1 r
F P
0 g
s
.37372 .85663 m .40461 .86079 L .34087 .88894 L p 0 .458 1 r
F P
0 g
s
.34087 .88894 m .31076 .88507 L .37372 .85663 L p 0 .458 1 r
F P
0 g
s
.4459 .1769 m .58647 .06381 L .59255 .61835 L p 0 .169 .684 r
F P
0 g
s
.3737 .85663 m .37372 .85663 L .31076 .88507 L p 0 .458 1 r
F P
0 g
s
.31076 .88507 m .31075 .88506 L .3737 .85663 L p 0 .458 1 r
F P
0 g
s
.22541 .8741 m .22928 .75157 L .35377 .68224 L p 0 .157 .671 r
F P
0 g
s
0 0 0 r
.228 .79203 m
.228 .79203 L
s
.228 .79203 m
.228 .79203 L
s
.3737 .85663 m .37432 .81457 L .4418 .78249 L p 0 .169 .684 r
F P
0 g
s
.44209 .73938 m .4418 .78249 L .37432 .81457 L p 0 .169 .684 r
F P
0 g
s
.4418 .78249 m .44151 .82601 L .3737 .85663 L p 0 .169 .684 r
F P
0 g
s
.31075 .88506 m .44151 .82601 L .44238 .69674 L p 0 .169 .684 r
F P
0 g
s
.44151 .82601 m .31075 .88506 L .22541 .8741 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.22671 .83287 m
.22671 .83287 L
s
.22671 .83287 m
.22671 .83287 L
s
.26838 .87962 m
.26838 .87962 L
s
.26838 .87962 m
.26838 .87962 L
s
.48662 .87184 m
.48662 .87184 L
s
.48662 .87184 m
.56851 .88286 L
s
.56851 .88286 m
.56851 .88286 L
s
.48662 .87184 m
.48662 .87184 L
s
.228 .79203 m
.228 .79203 L
s
.26838 .87962 m
.26838 .87962 L
s
.44477 .34298 m
.44477 .34298 L
s
.44477 .34298 m
.44477 .34298 L
s
.22671 .83287 m
.22671 .83287 L
s
.35377 .68224 m .35151 .81327 L .22541 .8741 L p 0 .157 .671 r
F P
0 g
s
.22541 .8741 m .35151 .81327 L .44151 .82601 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.44477 .34298 m
.44477 .34298 L
s
.55733 .84239 m .48662 .87184 L .4866 .87183 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.48662 .87183 m
.48667 .84006 L
s
.48662 .87184 m
.48662 .87184 L
s
.55732 .84239 m .4866 .87183 L .45657 .86779 L p 0 .458 1 r
F P
0 g
s
.4866 .87183 m .55732 .84239 L .55733 .84239 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.28922 .71819 m
.28922 .71819 L
s
.28922 .71819 m
.28922 .71819 L
s
.52653 .83803 m .45657 .86779 L .4307 .86431 L p 0 .458 1 r
F P
0 g
s
.45657 .86779 m .52653 .83803 L .55732 .84239 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.51359 .12244 m
.51359 .12244 L
s
.51359 .12244 m
.51359 .12244 L
s
.4307 .86431 m .5 .83428 L .52653 .83803 L p 0 .458 1 r
F P
0 g
s
.5 .83428 m .4307 .86431 L .40461 .86079 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.4436 .51611 m
.4436 .51611 L
s
.4436 .51611 m
.4436 .51611 L
s
.40461 .86079 m .47323 .83049 L .5 .83428 L p 0 .458 1 r
F P
0 g
s
.47323 .83049 m .40461 .86079 L .37372 .85663 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.51359 .12244 m
.51441 .60415 L
s
.51359 .12244 m
.51359 .12244 L
s
.63287 .81094 m
.64055 .81208 L
s
.37372 .85663 m .44152 .82601 L .47323 .83049 L p 0 .458 1 r
F P
0 g
s
.44152 .82601 m .37372 .85663 L .3737 .85663 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.3737 .85663 m
.3737 .85663 L
s
.3737 .85663 m
.3737 .85663 L
s
.3737 .85663 m .44151 .82601 L .44152 .82601 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.28609 .84483 m
.28609 .84483 L
s
.28609 .84483 m
.3737 .85663 L
s
.3737 .85663 m
.3737 .85663 L
s
.28609 .84483 m
.28609 .84483 L
s
.28609 .84483 m
.28922 .71819 L
s
.28922 .71819 m
.28922 .71819 L
s
.4436 .51611 m
.4436 .51611 L
s
.8042 .79017 m .64123 .85426 L .55733 .84239 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.46111 .90439 m
.59959 .84837 L
s
.59932 .82491 m
.59942 .83349 L
s
.59959 .84837 m
.59959 .84837 L
s
.59959 .84837 m
.59959 .84837 L
s
.59959 .84837 m
.59959 .84837 L
s
.59959 .84837 m
.59959 .84837 L
s
.65372 .65577 m
.66493 .6503 L
s
.67473 .64551 m
.68167 .64212 L
s
.59959 .84837 m
.59959 .84837 L
s
.64328 .07965 m .69896 .09518 L .71266 .64017 L p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.66196 .08486 m
.66196 .08486 L
s
.66196 .08486 m
.66196 .08486 L
s
.68052 .09004 m
.68052 .09004 L
s
.68052 .09004 m
.68052 .09004 L
s
.59286 .64619 m
.60821 .63839 L
s
.61153 .63671 m
.61736 .63375 L
s
.68052 .09004 m
.68052 .09004 L
s
.63359 .81064 m .55733 .84239 L .55732 .84239 L p 0 .458 1 r
F P
0 g
s
.55733 .84239 m .71608 .7763 L .8042 .79017 L p 0 .458 1 r
F P
0 g
s
.63358 .81064 m .55732 .84239 L .52653 .83803 L p 0 .458 1 r
F P
0 g
s
.55732 .84239 m .63358 .81064 L .63359 .81064 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.66196 .08486 m
.66196 .08486 L
s
.44238 .69674 m .44151 .82601 L .35151 .81327 L p 0 .351 .737 r
F P
0 g
s
.35151 .81327 m .44151 .82601 L .44238 .69674 L p 0 .351 .737 r
F P
0 g
s
.44238 .69674 m .35377 .68224 L .35151 .81327 L p 0 .351 .737 r
F P
0 g
s
.49902 .60135 m .35377 .68224 L .44238 .69674 L p 0 .455 1 r
F P
0 g
s
.602 .80593 m .52653 .83803 L .5 .83428 L p 0 .458 1 r
F P
0 g
s
.52653 .83803 m .602 .80593 L .63358 .81064 L p 0 .458 1 r
F P
0 g
s
.71266 .64017 m .65324 .62938 L .64328 .07965 L p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.66196 .08486 m
.67319 .633 L
s
.67319 .633 m
.67319 .633 L
s
.67319 .633 m
.67319 .633 L
s
.68052 .09004 m
.69299 .6366 L
s
.69299 .6366 m
.69299 .6366 L
s
.69299 .6366 m
.69299 .6366 L
s
.70333 .26888 m
.70333 .26888 L
s
.70333 .26888 m
.70333 .26888 L
s
.70789 .45036 m
.70789 .45036 L
s
.70789 .45036 m
.70789 .45036 L
s
.69299 .6366 m
.69299 .6366 L
s
.69299 .6366 m
.69299 .6366 L
s
.67319 .633 m
.67319 .633 L
s
.67319 .633 m
.67319 .633 L
s
.65349 .64274 m
.65914 .63994 L
s
.59255 .61835 m .58647 .06381 L .64328 .07965 L p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.59043 .42504 m
.59043 .42504 L
s
.4436 .51611 m
.59043 .42504 L
s
.58841 .24038 m
.58841 .24038 L
s
.44477 .34298 m
.58841 .24038 L
s
.60553 .06913 m
.60553 .06913 L
s
.60553 .06913 m
.60553 .06913 L
s
.62447 .07441 m
.62447 .07441 L
s
.62447 .07441 m
.62447 .07441 L
s
.64328 .07965 m .65324 .62938 L .59255 .61835 L p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.64977 .43783 m
.64977 .43783 L
s
.64977 .43783 m
.64977 .43783 L
s
.64645 .25477 m
.64645 .25477 L
s
.64645 .25477 m
.64645 .25477 L
s
.61291 .62206 m
.61291 .62206 L
s
.5927 .63246 m
.60046 .62847 L
s
.61293 .62205 m
.61293 .62205 L
s
.61293 .62205 m
.61293 .62205 L
s
.61293 .62205 m
.61293 .62205 L
s
.63315 .62573 m
.63315 .62573 L
s
.63316 .62572 m
.63316 .62572 L
s
.63316 .62572 m
.63316 .62572 L
s
.63316 .62572 m
.63316 .62572 L
s
.71957 .82345 m
.71957 .82345 L
s
.71957 .82345 m
.71957 .82345 L
s
.63316 .62572 m
.63316 .62572 L
s
.63316 .62572 m
.63316 .62572 L
s
.62447 .07441 m
.63316 .62572 L
s
.62447 .07441 m
.62447 .07441 L
s
.5 .83428 m .57478 .80188 L .602 .80593 L p 0 .458 1 r
F P
0 g
s
.57478 .80188 m .5 .83428 L .47323 .83049 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.39841 .68955 m
.39841 .68955 L
s
.54616 .60992 m
.54616 .60992 L
s
.54616 .60992 m
.54616 .60992 L
s
.61293 .62205 m
.61293 .62205 L
s
.61293 .62205 m
.61293 .62205 L
s
.60553 .06913 m
.61293 .62205 L
s
.60553 .06913 m
.60553 .06913 L
s
.47323 .83049 m .54731 .79778 L .57478 .80188 L p 0 .458 1 r
F P
0 g
s
.54731 .79778 m .47323 .83049 L .44152 .82601 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.64645 .25477 m
.64645 .25477 L
s
.64645 .25477 m
.64645 .25477 L
s
.64645 .25477 m
.70333 .26888 L
s
.70333 .26888 m
.70333 .26888 L
s
.44152 .82601 m .51475 .79293 L .54731 .79778 L p 0 .458 1 r
F P
0 g
s
.51475 .79293 m .44152 .82601 L .44151 .82601 L p 0 .458 1 r
F P
0 g
s
.44151 .82601 m .51474 .79293 L .51475 .79293 L p 0 .458 1 r
F P
0 g
s
.499 .74214 m .35151 .81327 L .35377 .68224 L p 0 .157 .671 r
F P
0 g
s
0 0 0 r
.42159 .77947 m
.4418 .78248 L
s
.39828 .7006 m
.39841 .68955 L
s
.35302 .72547 m
.35302 .72547 L
s
.35302 .72547 m
.35302 .72547 L
s
.35302 .72547 m
.35302 .72547 L
s
.35302 .72547 m
.35302 .72547 L
s
.35377 .68224 m .49902 .60135 L .499 .74214 L p 0 .157 .671 r
F P
0 g
s
.499 .74214 m .59407 .7571 L .44151 .82601 L p 0 .458 1 r
F P
0 g
s
.44151 .82601 m .35151 .81327 L .499 .74214 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.22671 .83287 m
.35227 .76915 L
s
.228 .79203 m
.35302 .72547 L
s
.35227 .76915 m
.35227 .76915 L
s
.35227 .76915 m
.35227 .76915 L
s
.35227 .76915 m
.35227 .76915 L
s
.35227 .76915 m
.35227 .76915 L
s
.39685 .81969 m
.39685 .81969 L
s
.39685 .81969 m
.39685 .81969 L
s
.39685 .81969 m
.39685 .81969 L
s
.39685 .81969 m
.39685 .81969 L
s
.26838 .87962 m
.39685 .81969 L
s
.63359 .81064 m
.63359 .81064 L
s
.63359 .81064 m
.71957 .82345 L
s
.71957 .82345 m
.71957 .82345 L
s
.35302 .72547 m
.35302 .72547 L
s
.39685 .81969 m
.39685 .81969 L
s
.58841 .24038 m
.58841 .24038 L
s
.58841 .24038 m
.64645 .25477 L
s
.64645 .25477 m
.64645 .25477 L
s
.35227 .76915 m
.35227 .76915 L
s
.63359 .81064 m .71608 .7763 L .71492 .73044 L p 0 .183 .697 r
F P
0 g
s
.63359 .81064 m .63358 .81064 L .71606 .7763 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.63307 .77663 m
.63359 .81063 L
s
.63359 .81064 m
.63359 .81064 L
s
.63359 .81064 m
.63359 .81064 L
s
.71606 .7763 m .71608 .7763 L .63359 .81064 L p 0 .458 1 r
F P
0 g
s
.63358 .81064 m .602 .80593 L .68367 .7712 L p 0 .458 1 r
F P
0 g
s
.68367 .7712 m .71606 .7763 L .63358 .81064 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.64977 .43783 m
.64977 .43783 L
s
.64977 .43783 m
.64977 .43783 L
s
.64977 .43783 m
.70789 .45036 L
s
.70789 .45036 m
.70789 .45036 L
s
.42349 .64341 m
.42349 .64341 L
s
.42349 .64341 m
.42349 .64341 L
s
.68367 .7712 m .602 .80593 L .57478 .80188 L p 0 .458 1 r
F P
0 g
s
.71266 .64017 m .79946 .65595 L .8042 .79017 L p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.8026 .74496 m
.8026 .74496 L
s
.8026 .74496 m
.8026 .74496 L
s
.7564 .64812 m
.7564 .64812 L
s
.7564 .64812 m
.7564 .64812 L
s
.80102 .70022 m
.80102 .70022 L
s
.80102 .70022 m
.80102 .70022 L
s
.57478 .80188 m .65573 .7668 L .68367 .7712 L p 0 .458 1 r
F P
0 g
s
.65573 .7668 m .57478 .80188 L .54731 .79778 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.59043 .42504 m
.59043 .42504 L
s
.59043 .42504 m
.64977 .43783 L
s
.64977 .43783 m
.64977 .43783 L
s
.80102 .70022 m
.80102 .70022 L
s
.54731 .79778 m .62752 .76236 L .65573 .7668 L p 0 .458 1 r
F P
0 g
s
.59409 .7571 m .62752 .76236 L .54731 .79778 L p 0 .458 1 r
F P
0 g
s
.54731 .79778 m .51475 .79293 L .59409 .7571 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.7564 .64812 m
.7564 .64812 L
s
.8026 .74496 m
.8026 .74496 L
s
.59407 .7571 m .59409 .7571 L .51475 .79293 L p 0 .458 1 r
F P
0 g
s
.51475 .79293 m .51474 .79293 L .59407 .7571 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.51474 .79293 m
.51474 .79293 L
s
.51474 .79293 m
.51474 .79293 L
s
.42226 .77915 m
.42226 .77915 L
s
.42226 .77915 m
.51474 .79293 L
s
.51474 .79293 m
.51474 .79293 L
s
.51474 .79293 m
.51474 .79293 L
s
.42226 .77915 m
.42226 .77915 L
s
.42226 .77915 m
.42349 .64341 L
s
.42349 .64341 m
.42349 .64341 L
s
.8042 .79017 m .71608 .7763 L .71266 .64017 L p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.7564 .64812 m
.76049 .78329 L
s
.76049 .78329 m
.76049 .78329 L
s
.59959 .84837 m
.76049 .78329 L
s
.76049 .78329 m
.76049 .78329 L
s
.71266 .6402 m .71378 .68505 L .69555 .65706 L closepath p 0 .351 .727 r
F P
0 g
s
.67824 .67413 m .69555 .65706 L .71378 .68505 L p 0 .351 .727 r
F P
0 g
s
.71378 .68505 m .71492 .73044 L .67824 .67413 L p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.71492 .73044 m
.71492 .73044 L
s
.65555 .75647 m
.71492 .73044 L
s
.71492 .73044 m
.71492 .73044 L
s
.65475 .71224 m
.69192 .69513 L
s
.71378 .68507 m
.71378 .68507 L
s
.71378 .68507 m
.71378 .68507 L
s
.71378 .68507 m
.71378 .68507 L
s
.71378 .68507 m
.71378 .68507 L
s
.71378 .68507 m
.80102 .70022 L
s
.71492 .73044 m
.71492 .73044 L
s
.71492 .73044 m
.71492 .73044 L
s
.71492 .73044 m
.8026 .74496 L
s
.69555 .65706 m .67824 .67413 L .6732 .633 L p 0 .351 .727 r
F P
0 g
s
.65324 .62938 m .66072 .69139 L .65448 .69755 L closepath p 0 .351 .727 r
F P
0 g
s
.65448 .69755 m .64796 .68921 L .65324 .62938 L closepath p 0 .351 .727 r
F P
0 g
s
.67824 .67413 m .66072 .69139 L .65324 .62938 L p 0 .351 .727 r
F P
0 g
s
.66072 .69139 m .67824 .67413 L .71492 .73044 L p 0 .351 .727 r
F P
0 g
s
.71606 .7763 m .66072 .69139 L p .71492 .73044 L 0 .351 .727 r
F P
0 g
s
.71492 .73044 m .71608 .7763 L .71606 .7763 L p 0 .351 .727 r
F P
0 g
s
.64796 .68921 m .62951 .66563 L .63315 .62572 L p 0 .351 .727 r
F P
0 g
s
.65448 .69755 m .66072 .69139 L .71606 .7763 L p 0 .351 .727 r
F P
0 g
s
.65502 .72726 m .65448 .69755 L p .71606 .7763 L 0 .351 .727 r
F P
0 g
s
.71606 .7763 m .68367 .7712 L .65502 .72726 L p 0 .351 .727 r
F P
0 g
s
.62951 .66563 m .61103 .642 L .61291 .62205 L p 0 .351 .727 r
F P
0 g
s
.64796 .68921 m .65448 .69755 L .65502 .72726 L p 0 .351 .727 r
F P
0 g
s
.62752 .76236 m .59409 .7571 L .64796 .68921 L p 0 .351 .727 r
F P
0 g
s
.65502 .72726 m .62752 .76236 L p .64796 .68921 L 0 .351 .727 r
F P
0 g
s
.62951 .66563 m .64796 .68921 L .59409 .7571 L p 0 .351 .727 r
F P
0 g
s
.59407 .7571 m .59356 .71035 L .62951 .66563 L p 0 .351 .727 r
F P
0 g
s
.59409 .7571 m .59407 .7571 L p .62951 .66563 L 0 .351 .727 r
F P
0 g
s
.61103 .642 m .62951 .66563 L .59356 .71035 L p 0 .351 .727 r
F P
0 g
s
.61103 .642 m .59255 .61838 L .59255 .61835 L p 0 .351 .727 r
F P
0 g
s
.59356 .71035 m .59305 .66408 L .61103 .642 L p 0 .351 .727 r
F P
0 g
s
.61103 .642 m .59305 .66408 L .59255 .61838 L closepath p 0 .351 .727 r
F P
0 g
s
.59255 .61835 m .59407 .7571 L .499 .74214 L p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.59305 .6641 m
.59305 .6641 L
s
.59305 .6641 m
.59305 .6641 L
s
.59356 .71034 m
.59356 .71034 L
s
.59356 .71034 m
.59356 .71034 L
s
.54693 .74968 m
.54693 .74968 L
s
.39685 .81969 m
.54693 .74968 L
s
.35227 .76915 m
.49901 .69469 L
s
.49901 .69469 m
.49901 .69469 L
s
.35302 .72547 m
.49901 .64776 L
s
.49901 .64776 m
.49901 .64776 L
s
.68367 .7712 m .65573 .7668 L .65502 .72726 L closepath p 0 .351 .727 r
F P
0 g
s
.65502 .72726 m .65573 .7668 L .62752 .76236 L closepath p 0 .351 .727 r
F P
0 g
s
0 0 0 r
.49901 .64776 m
.49901 .64776 L
s
.49901 .64776 m
.59305 .6641 L
s
.59305 .6641 m
.59305 .6641 L
s
.59305 .6641 m
.59305 .6641 L
s
.54693 .74968 m
.54693 .74968 L
s
.54616 .60992 m
.54693 .74968 L
s
.54616 .60992 m
.54616 .60992 L
s
.49901 .69469 m
.49901 .69469 L
s
.49901 .69469 m
.59356 .71034 L
s
.59356 .71034 m
.59356 .71034 L
s
.59356 .71034 m
.59356 .71034 L
s
0 g
[ .01 .01 ] 0 setdash
.49903 .0149 m
.79464 .09859 L
s
.79464 .09859 m
.82095 .80615 L
s
.82095 .80615 m
.49894 .75626 L
s
.49894 .75626 m
.49903 .0149 L
s
.23322 .24553 m
.21183 .8926 L
s
.21183 .8926 m
.49894 .75626 L
s
.49894 .75626 m
.49903 .0149 L
s
.49903 .0149 m
.23322 .24553 L
s
.003 w
[ ] 0 setdash
.23322 .24553 m
.49903 .0149 L
s
.25 Mabswid
.23868 .24079 m
.24476 .24221 L
s
gsave
.22651 .23795 -91.25 -12.6348 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.29533 .19164 m
.3014 .19312 L
s
gsave
.28318 .18868 -85.25 -12.7078 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.35606 .13895 m
.36212 .14049 L
s
gsave
.34395 .13586 -71 -12.7875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.42134 .08231 m
.42738 .08393 L
s
gsave
.40927 .07907 -77 -12.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.4917 .02127 m
.49771 .02296 L
s
gsave
.47966 .01788 -83 -12.9716 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.2497 .23123 m
.25335 .23209 L
s
.26087 .22153 m
.26452 .2224 L
s
.2722 .21171 m
.27585 .21258 L
s
.28368 .20174 m
.28733 .20263 L
s
.30713 .1814 m
.31077 .1823 L
s
.3191 .17101 m
.32274 .17192 L
s
.33125 .16048 m
.33489 .16139 L
s
.34356 .14979 m
.3472 .15071 L
s
.36874 .12795 m
.37237 .12889 L
s
.3816 .11679 m
.38523 .11773 L
s
.39465 .10547 m
.39828 .10642 L
s
.4079 .09397 m
.41152 .09494 L
s
.43499 .07047 m
.43861 .07145 L
s
.44884 .05845 m
.45246 .05944 L
s
.46291 .04624 m
.46652 .04724 L
s
.47719 .03385 m
.4808 .03486 L
s
gsave
.28339 .12039 -76.625 -12.7875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.79464 .09859 m
.82095 .80615 L
s
.25 Mabswid
.80243 .30805 m
.79636 .30657 L
s
gsave
.81457 .31103 -61 -9.28291 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.81261 .58192 m
.80648 .58072 L
s
gsave
.82488 .58432 -61 -9.63014 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.80441 .36139 m
.80076 .36053 L
s
.80642 .41543 m
.80276 .41461 L
s
.80846 .47019 m
.80479 .4694 L
s
.81052 .52568 m
.80685 .52493 L
s
.80047 .25541 m
.79684 .25448 L
s
.79854 .20344 m
.79491 .20248 L
s
.79663 .15214 m
.79301 .15115 L
s
.79475 .10148 m
.79114 .10046 L
s
.81473 .63892 m
.81105 .63824 L
s
.81688 .6967 m
.81319 .69606 L
s
.81906 .75528 m
.81536 .75467 L
s
gsave
.88045 .4535 -61 -9.44655 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00/`3oool3
000006X0oooo002c0?ooo`030>k^kP000000k^k^06X0oooo002d0?ooo`030000003oool0oooo06T0
oooo002c0?ooo`030>k^kP000000k^k^06X0oooo002c0?ooo`<0A4A4JP3oool00;80oooo00D0QhN7
04A4A03oool0<S8b0:VYZ@1Y0?ooo`00/@3oool01`3<c<`000000>k^kP3oool0c<c<0000003<c<`0
J03oool00;40oooo0P0000000`0b<S80oooo00000002000006P0oooo002D0?ooo`07010@40000000
00000000002HV9P0oooo09RHV0030000000309RHV03oool0oooo07l0oooo002G0?ooo`0809RHV000
0000oooo0000002HV9P0oooo09RHV00000210?ooo`00V03oool00`000000oooo000000030?ooo`03
0000003oool0oooo07l0oooo002=0?ooo`L00000103oool00`000000oooo000000030?ooo`030000
003oool0oooo07l0oooo002G0?ooo`0409RHV0000000oooo000000<0oooo00<000000?ooo`3oool0
O`3oool009@0oooo100000000`2HV9P0oooo000000030?ooo`030000003oool0oooo00@0oooo1000
00000`2j^[X0oooo010@40030000000309RHV03oool0oooo06h0oooo002D0?ooo`0307MgM`1EEED0
oooo00<0oooo00D0000009RHV03oool0V9RH000000060?ooo`050<c<c03^k^h0oooo0<c<c01EEED0
103oool00`2HV9P000000?ooo`1_0?ooo`00N03oool3000000030?ooo`2HV9P000000080000000<0
V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`0<0?ooo`06010@400000000000038b<P3oool0
V9RH0`0000000`2HV9P0oooo0?ooo`050?ooo`030<c<c03^k^h0oooo00H0oooo00<000000?ooo`3o
ool0KP3oool007T0oooo00h000000?ooo`3oool0000009RHV03oool0V9RH0000003oool0000009RH
V03oool0V9RH000001L0oooo1`0000020?ooo`030:VYZ@3^k^h0oooo00D0oooo00<000000?ooo`3o
ool0KP3oool007T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo01h0oooo00<0gMgM06IVIP3oool0103oool00`2HV9P000000?ooo`030?ooo`05
09RHV000000000000000002HV9P0I`3oool007T0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00D0oooo1000000C0?ooo`0407MgM`3oool0oooo
00000080oooo100000000`2HV9P0oooo0?ooo`020?ooo`050000002HV9P0oooo09RHV0000000I`3o
ool007T0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00@0oooo0`0000000`3oool000000000000200000100oooo00@0000009RHV02HV9P00000
0P3oool00`1gMgL0EEEE0?ooo`060?ooo`050000003oool0oooo0?ooo`000000I`3oool007T0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo00<0
oooo0`0000030?ooo`030000003oool0000000@00000303oool0102HV9P000000000002HV9P30?oo
o`04010@400000000000038b<P@0oooo00D000000?ooo`3oool0oooo0000001W0?ooo`00N@3oool0
3P000000oooo0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000103o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`00000H0?ooo`050000
003oool0oooo0?ooo`000000I`3oool007P0oooo00D08B4Q0000003oool0oooo09RHV00300000003
09RHV03oool0V9RH00<0000000@0V9RH0?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000P3oool3000001D0oooo00D000000?ooo`3oool0oooo0000
00080?ooo`@0000000<0^[Zj0?ooo`0@41000`0000000`2HV9P0oooo0?ooo`1B0?ooo`00R@3oool2
000000@0oooo00<000000?ooo`3oool02`3oool600000140oooo00D0000009RHV03oool0V9RH0000
00080?ooo`050<c<c03^k^h0oooo0<c<c01EEED0103oool00`2HV9P000000?ooo`1C0?ooo`00Q`3o
ool2000000H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03000000h0oooo00D0
V9RH000000000000000009RHV0090?ooo`030<c<c03^k^h0oooo00H0oooo00<000000?ooo`3oool0
DP3oool008H0oooo0P00000L0?ooo`030000003oool0000000@00000603oool00`2YZJT0k^k^0?oo
o`050?ooo`030000003oool0oooo0580oooo00250?ooo`800000803oool00`000000oooo0?ooo`03
000001H0oooo00<0gMgM06IVIP3oool0103oool00`2HV9P000000?ooo`040?ooo`07010@40000000
00000000002HV9P0oooo09RHV0030000000309RHV03oool0oooo0480oooo00240?ooo`<00000203o
ool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo00000080oooo1000000@0?ooo`0407Mg
M`3oool0oooo00000080oooo100000000`2HV9P0oooo0?ooo`060?ooo`0809RHV0000000oooo0000
002HV9P0oooo09RHV00000140?ooo`00P`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`0000001000000<0?ooo`040000002HV9P0V9RH00000080oooo00<0
MgMg05EEE@3oool02`3oool00`000000oooo000000030?ooo`030000003oool0oooo0480oooo0022
0?ooo`8000002`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00@000002@3oool0
102HV9P000000000002HV9P30?ooo`04010@400000000000038b<PT0oooo00<000000?ooo`000000
0`3oool00`000000oooo0?ooo`120?ooo`00P03oool300000340oooo00<000000?ooo`3oool01000
000I0?ooo`0409RHV0000000oooo000000<0oooo00<000000?ooo`3oool0@P3oool006T0oooo00L0
410@000000000000000009RHV03oool0V9RH00<0000000<0V9RH0?ooo`3oool02@3oool00`000000
oooo0?ooo`0S0?ooo`@000003P3oool010000000oooo0?ooo`3oool500000140oooo100000000`2H
V9P0oooo000000030?ooo`030000003oool0oooo0480oooo001/0?ooo`0809RHV0000000oooo0000
002HV9P0oooo09RHV000000:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3o
ool00`00000002^_00000002001I^P@000003P3oool00`000000oooo0?ooo`04000000l0oooo00<0
MgMg05EEE@3oool00`3oool01@000000V9RH0?ooo`2HV9P0000004@0oooo001]0?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01`3oool3000000l0oooo00<000000?ooo`3oool04@3o
ool01000000002^_000[[`000004001I^P0300000000FKX00000008000004@3oool5000000`0oooo
00H0410@000000000000<S8b0?ooo`2HV9P30000000309RHV03oool0oooo0480oooo001]0?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0100oooo00D00000000[[`00:jl002^_00000004001I^P0300000000FKX005Vj
008005Vj1000000@0?ooo`H00000EP3oool006`0oooo00@0V9RH0000003oool000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool20000
00@002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0400000000FKX005Vj
001I^P@00000403oool4000005@0oooo001Y0?ooo`@0000000<0V9RH0?ooo`0000000`3oool00`00
0000oooo0?ooo`030?ooo`<000008`3oool00`00000002^_000[[`04000[[`0300000000FKX005Vj
008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj
00<000003@3oool00`000000oooo0?ooo`0500000500oooo001Y0?ooo`0307MgM`1EEED0oooo00<0
oooo00D0000009RHV03oool0V9RH000000040?ooo`8000000P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00`0oooo00<00000000[[`00:jl01@00:jl00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P@00000403oool00`000000oooo00000003000004`0oooo001Z0?ooo`06010@400000000000038b
<P3oool0V9RH0`0000001@2HV9P0oooo0?ooo`3oool0000001L0oooo00<000000?ooo`3oool02`3o
ool00`00000002^_000[[`06000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00@00000001I^P00FKX005Vj
0`00000@0?ooo`030000003oool0000000800000BP3oool007H0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0:0?ooo`0300000000:jl002^_00L002^_00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX0000000800000403oool00`000000oooo0000
0004000004D0oooo001e0?ooo`030000003oool0000001L0oooo00<000000?ooo`3oool0203oool2
000000X002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX0
05Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX0
05Vj008005Vj00<000000?ooo`3oool04@3oool00`000000oooo0000000400000440oooo001d0?oo
o`030000003oool0oooo0280oooo00<00000000[[`00:jl02P00:jl00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0D0?oo
o`040000003oool0000000000440oooo001c0?ooo`030000003oool0oooo0280oooo00<00000000[
[`00:jl02`00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I
^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I
^P00FKX00P00FKX00`000000oooo0?ooo`0E0?ooo`030000003oool000000440oooo00170?ooo`<0
000000<0oooo07MgM`0000000P00000R0?ooo`80000000<0oooo0000003oool06@3oool00`000000
oooo0?ooo`050?ooo`0300000000:jl002^_00`002^_00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0503oool010000000
oooo0?ooo`0000110?ooo`00B03oool01P2HV9P0MgMg0?ooo`3oool08B4Q0:VYZB80oooo0P00000M
0?ooo`030000003oool0oooo00<0oooo0P00000?000[[`0300000000FKX005Vj008005Vj00<00000
001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000
001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01<0oooo00D00000
0?ooo`3oool0oooo000000110?ooo`00B@3oool0101EEED0V9RH07MgM`1VIVHR0?ooo`8000007P3o
ool00`000000oooo0?ooo`020?ooo`0300000000:jl002^_00l002^_00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03l0oooo00190?ooo`030>k^kP0Q8B40
<S8b0280oooo00<000000?ooo`0000008P3oool00`00000002^_000[[`0@000[[`0300000000FKX0
05Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX0
05Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000003oool0
oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0o0?ooo`00B@3oool00`3^
k^h0410@038b<P0A0?ooo`0509RHV000000000000000002HV9P02`3oool00`000000oooo0?ooo`0R
0?ooo`8000004P00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000
001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000
001I^P00FKX00P00FKX00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0?`3oool004T0oooo00@0IVIV07MgM`2YZJT0IVIV403oool01@000000V9RH0?ooo`2H
V9P0000000X0oooo00<000000?ooo`3oool0803oool01@000000oooo00000000:jl00000018002^_
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03l0oooo
00180?ooo`040:VYZ@0Q8B40oooo0?ooo`80V9RH00<0k^k^0?ooo`3oool0303oool01@000000oooo
0?ooo`3oool0000000P0oooo0P0000000`3oool000000?ooo`0P0?ooo`8000000P00:jl00`000000
02^_000[[`0@000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0o0?ooo`00A`3oool30000000307MgM`3oool0<S8b0080000000<0^[Zj0?ooo`3oool0
2`3oool01@000000oooo0?ooo`3oool0000000L0oooo0P00000S0?ooo`8000000`00:jl00`000000
02^_000[[`0@000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0o0?ooo`00G@3oool01@000000oooo0?ooo`3oool0000000H0oooo0P00000S0?ooo`03
00000000:jl0000000<002^_00<00000000[[`00:jl04000:jl00`00000005Vj001I^P02001I^P03
00000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P03
00000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo03l0oooo001M0?ooo`050000003oool0oooo0?ooo`0000001@3oool200000003
0?ooo`000000oooo0200oooo00<00000000[[`00:jl01000:jl00`00000002^_000[[`0@000[[`03
00000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P03
00000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P03
0000003oool0oooo00L0oooo0P00000>0?ooo`030000003oool0oooo03l0oooo001M0?ooo`050000
002HV9P0oooo09RHV0000000103oool00`000000oooo0?ooo`0Q0?ooo`8000000`00:jl01@000000
02^_000[[`00:jl00000018002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool01@3oool200000100oooo0P0000100?oo
o`00G@3oool01@2HV9P00000000000000000V9RH00<0oooo00<000000?ooo`3oool08@3oool00`00
000002^_000[[`03000[[`0500000000:jl002^_000[[`0000004P00:jl00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0G
0?ooo`800000@03oool006<0oooo0P0000000`3oool000000?ooo`0P0?ooo`0300000000:jl002^_
00@002^_00D00000000[[`00:jl002^_0000000B000[[`0300000000FKX005Vj008005Vj00<00000
001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000
001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo0080oooo0P00000C
0?ooo`800000@03oool00680oooo00<000000?ooo`3oool08P3oool00`00000002^_000[[`05000[
[`0500000000:jl002^_000[[`0000004P00:jl00`00000005Vj001I^P02001I^P0300000000FKX0
05Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX0
05Vj008005Vj00<00000001I^P00FKX00P00FKX01@000000oooo0?ooo`3oool0000001H0oooo00<0
00000?ooo`3oool0?P3oool00640oooo0`00000R0?ooo`0300000000:jl002^_00X002^_00<00000
000[[`00:jl04000:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000
001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00D00000
001I^P00FKX005Vj0000000J0?ooo`030000003oool0oooo03h0oooo001P0?ooo`8000008P3oool2
000000d002^_00<00000000[[`00:jl04000:jl00`00000005Vj001I^P02001I^P0300000000FKX0
05Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX0
05Vj00<005Vj00@00000001I^P00FKX005Vj0`00000H0?ooo`030000003oool0oooo03h0oooo001O
0?ooo`8000008P3oool00`00000002^_000[[`09000[[`0500000000:jl002^_000[[`0000004P00
:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00
FKX00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03h0oooo001N0?ooo`8000008P3oool0
0`00000002^_000[[`0:000[[`0500000000:jl002^_000[[`0000004P00:jl00`00000005Vj001I
^P02001I^P0300000000FKX005Vj00<005Vj00D00000001I^P00FKX005Vj00000004001I^P030000
0000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo03h0oooo00170?ooo`07010@4000000000000000002HV9P0oooo09RHV00300000003
09RHV03oool0oooo00P0oooo0P00000S0?ooo`0300000000:jl002^_00/002^_00D00000000[[`00
:jl002^_0000000B000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00
000005Vj001I^P02001I^P0500000000FKX005Vj001I^P0000001@00FKX00`00000005Vj001I^P02
001I^P030000003oool0oooo01L0oooo00<000000?ooo`3oool0?P3oool004X0oooo00P0V9RH0000
003oool0000009RHV03oool0V9RH000000T0oooo0P00000R0?ooo`8000004P00:jl00`00000002^_
000[[`0@000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P030000003oool0oooo01L0oooo00<000000?ooo`3oool0?P3oool004/0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`060?ooo`<000008@3oool00`00000002^_000[
[`0B000[[`0300000000:jl002^_010002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0n0?ooo`00@03oool7000000@0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`05
0?ooo`8000008P3oool01000000002^_000[[`00000>000[[`0500000000:jl002^_000[[`000000
4P00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03h0oooo001:0?ooo`0409RHV000
0000oooo000000<0oooo00<000000?ooo`3oool0103oool200000280oooo00D00000000[[`00:jl0
02^_0000000>000[[`0500000000:jl002^_000[[`0000004P00:jl00`00000005Vj001I^P02001I
^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo03h0oooo00170?ooo`@0000000<0V9RH0?ooo`0000000`3oool00`000000
oooo0?ooo`030?ooo`@000007`3oool2000000@002^_00<00000000[[`00:jl03000:jl01@000000
02^_000[[`00:jl00000018002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0n0?oo
o`00A`3oool00`1gMgL0EEEE0?ooo`030?ooo`050000002HV9P0oooo09RHV0000000103oool00`00
0000oooo0?ooo`0P0?ooo`0300000000:jl002^_00@002^_00<00000000[[`00:jl03000:jl01@00
000002^_000[[`00:jl00000018002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0n
0?ooo`00B03oool01P0@410000000000000b<S80oooo09RHV0<0000000<0V9RH0?ooo`3oool00`00
000Q0?ooo`0300000000:jl002^_00D002^_00<00000000[[`00:jl04000:jl00`00000002^_000[
[`0@000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I
^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P02001I^P030000003oool0oooo01H0oooo0P0000100?ooo`00D`3oool200000280oooo00<00000
000[[`00:jl01P00:jl00`00000002^_000[[`0@000[[`0300000000:jl002^_014002^_00D00000
001I^P00FKX005Vj00000005001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0n0?ooo`00DP3oool00`000000oooo0?ooo`0Q0?ooo`0300000000:jl0
02^_00L002^_00<00000000[[`00:jl03000:jl01@00000002^_000[[`00:jl0000001<002^_00D0
0000001I^P00FKX005Vj00000005001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0n0?ooo`00D@3oool300000200oooo0P00000:000[[`0300000000
:jl002^_00`002^_00D00000000[[`00:jl002^_0000000C000[[`0300000000FKX005Vj008005Vj
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01L0oooo
00<000000?ooo`3oool0?P3oool00500oooo0P00000Q0?ooo`0300000000:jl002^_00X002^_00<0
0000000[[`00:jl03000:jl01@00000002^_000[[`00:jl0000001<002^_00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0n0?ooo`00C`3oool200000240oooo00<00000000[[`00:jl02`00
:jl00`00000002^_000[[`0@000[[`0300000000:jl002^_014002^_00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0n0?ooo`00=03oool3000000030?ooo`2HV9P000000080000000<0V9RH
0?ooo`2HV9P00`0000000`2HV9P0oooo0?ooo`080?ooo`@00000803oool00`00000002^_000[[`0<
000[[`0300000000:jl002^_010002^_00<00000000[[`00:jl04@00:jl00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo03h0oooo000e0?ooo`0>0000003oool0oooo0000002HV9P0oooo09RH
V0000000oooo0000002HV9P0oooo09RHV00000090?ooo`8000008@3oool2000000l002^_00<00000
000[[`00:jl03000:jl01@00000002^_000[[`00:jl0000001<002^_00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0n0?ooo`00=@3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01P3oool300000200oooo00<00000000[[`0000003`00
:jl00`00000002^_000[[`0<000[[`0500000000:jl002^_000[[`0000004`00:jl00`00000005Vj
001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo03h0oooo000Z0?ooo`L00000103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0P0?ooo`0400000000:jl002^_000000l002^_00<00000000[[`00:jl03000:jl01@000000
02^_000[[`00:jl0000001<002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0n0?oo
o`00=@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool0103oool200000240oooo00D00000000[[`00:jl002^_0000000?000[[`0300000000:jl0
02^_00`002^_00D00000000[[`00:jl002^_0000000C000[[`0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0?P3oool003D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo00<0oooo0`00000O0?ooo`8000001000:jl00`00000002^_000[
[`0=000[[`0300000000:jl002^_010002^_00<00000000[[`00:jl04000:jl500000003001I^P00
000005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000
FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo03h0oooo000e0?ooo`0>0000003oool0oooo0000002HV9P0oooo09RHV0000000oooo0000
002HV9P0oooo09RHV00000040?ooo`@000007P3oool00`00000002^_000[[`04000[[`0300000000
:jl002^_00d002^_00<00000000[[`00:jl03000:jl01@00000002^_000[[`00:jl00000014002^_
00<00000000[[`0000000`00FKX500000003001I^P00000005Vj00<005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0
5`3oool2000003l0oooo000d0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0oooo
09RHV0030000000309RHV03oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000L0?ooo`03
00000000:jl002^_00D002^_00<00000000[[`00:jl03@00:jl00`00000002^_000[[`0<000[[`05
00000000:jl002^_000[[`0000003`00:jl20000008002^_00<00000001I^P00FKX00P00FKX01000
000005Vj001I^P00FKX500000003001I^P00000005Vj00<005Vj00<00000001I^P00FKX00P00FKX0
0`00000005Vj001I^P02001I^P030000003oool0oooo01L0oooo0P00000o0?ooo`00A`3oool00`00
0000oooo0?ooo`040?ooo`<000005P3oool00`00000002^_000[[`06000[[`0300000000:jl002^_
00d002^_00<00000000[[`00:jl03000:jl01@00000002^_000[[`00:jl0000000h002^_00<00000
000[[`00:jl00P00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00@00000
001I^P00FKX005Vj10000002001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`000000oooo0?ooo`0G0?ooo`800000?`3oool004L0oooo00<000000?ooo`3oool02@3oool4
000000l0oooo00<00000000[[`00:jl01`00:jl00`00000002^_000[[`0=000[[`0300000000:jl0
02^_00`002^_00D00000000[[`00:jl002^_0000000<000[[`8000001@00:jl00`00000005Vj001I
^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P04000000<005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo03d0oooo001H0?ooo`<000002@3oool2000000X002^_00<00000000[[`00:jl03@00:jl0
0`00000002^_000[[`0@000[[`0300000000:jl002^_00T002^_00<00000000[[`00:jl01@00:jl0
0`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX0
0`00000005Vj001I^P02001I^P0300000000FKX0000000<000001000FKX00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo03d0oooo00170?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool00P0000030?ooo`0300000000:jl002^_00X002^_00<00000000[[`00:jl03@00:jl00`00
000002^_000[[`0@000[[`0300000000:jl002^_00P002^_00<00000000[[`00:jl01P00:jl00`00
000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj1P00000J0?ooo`030000003oool0oooo
03d0oooo00170?ooo`030000003oool0oooo01H0oooo00<000000?ooo`0000003@00:jl00`000000
02^_000[[`0=000[[`0300000000:jl002^_00`002^_00D00000000[[`00:jl002^_00000008000[
[`8000002@00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I
^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I
^P00FKX00P00FKX2000001T0oooo00<000000?ooo`3oool0?@3oool004L0oooo00<000000?ooo`3o
ool05`3oool00`00000002^_000[[`0<000[[`0300000000:jl002^_00d002^_00<00000000[[`00
:jl03000:jl01@00000002^_000[[`00:jl0000000L002^_00<00000000[[`00:jl02@00:jl00`00
000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo03d0oooo00170?ooo`030000003oool0oooo01H0
oooo00<00000000[[`00:jl03@00:jl00`00000002^_000[[`0=000[[`0300000000:jl002^_00`0
02^_00D00000000[[`00:jl002^_00000005000[[`8000003000:jl00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo03d0oooo001P0?ooo`0300000000:jl002^_00d002^_00<00000000[[`00
:jl03@00:jl00`00000002^_000[[`0@000[[`0300000000:jl002^_008002^_00<00000000[[`00
:jl03000:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00
FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00
FKX00P00FKX00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03d0oooo001P0?ooo`030000
0000:jl002^_00d002^_00<00000000[[`00:jl03@00:jl00`00000002^_000[[`0@000[[`030000
0000:jl002^_008000003`00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj
00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03d0oooo
00170?ooo`030000003oool0oooo01H0oooo00<00000000[[`00:jl03@00:jl00`00000002^_000[
[`0=000[[`0300000000:jl002^_00`002^_00L00000000[[`00:jl002^_00000000:jl000000140
02^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj0080
05Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj0080
05Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0m0?ooo`00A`3oool00`000000oooo
0?ooo`0F0?ooo`0300000000:jl002^_00d002^_00<00000000[[`00:jl03@00:jl00`00000002^_
000[[`0<000[[`0400000000:jl002^_000[[`8000004P00:jl00`00000005Vj001I^P02001I^P03
00000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P03
00000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo03d0oooo00170?ooo`030000003oool0oooo01H0oooo00<00000000[[`00:jl0
3@00:jl00`00000002^_000[[`0=000[[`0300000000:jl002^_00`002^_00<00000000[[`00:jl0
0P00000C000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0?@3oool00600oooo00<0
0000000[[`00:jl03@00:jl00`00000002^_000[[`0=000[[`0300000000:jl002^_00`002^_00D0
0000000[[`00000002^_0000000C000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0`00FKX01@00000005Vj001I^P00FKX0000001X0oooo00<000000?ooo`3oool0?@3oool00600oooo
00<00000000[[`00:jl03@00:jl00`00000002^_000[[`0=000[[`0300000000:jl002^_00`002^_
0P000002000[[`0300000000:jl002^_014002^_00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P03001I^P0500000000FKX005Vj001I^P0000006P3oool00`000000oooo0?ooo`0m0?ooo`00
A`3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl002^_00d002^_00<00000000[[`00:jl0
3@00:jl00`00000002^_000[[`0;000[[`8000000`00:jl00`00000002^_000[[`0A000[[`030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000
003oool0oooo01H0oooo0P00000o0?ooo`00A`3oool00`000000oooo0?ooo`0F0?ooo`0300000000
:jl002^_00d002^_00<00000000[[`00:jl03@00:jl00`00000002^_000[[`09000[[`80000000<0
02^_00000000:jl00P00:jl00`00000002^_000[[`0A000[[`0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0103oool3000000030?ooo`2HV9P000000080000000<0V9RH0?ooo`2HV9P00`00
00000`2HV9P0oooo0?ooo`0X0?ooo`00A`3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl0
02^_00d002^_00<00000000[[`00:jl03@00:jl00`00000002^_000[[`08000[[`0500000000:jl0
02^_000[[`0000000`00:jl00`00000002^_000[[`0A000[[`0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01L0oooo00<0
00000?ooo`3oool01@3oool03P000000oooo0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000
V9RH0?ooo`2HV9P00000:P3oool004L0oooo00<000000?ooo`3oool05P3oool00`00000002^_000[
[`0=000[[`0300000000:jl002^_00d002^_00<00000000[[`00:jl01P00:jl2000000@002^_00D0
0000000[[`00:jl002^_0000000C000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0`00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool0:03oool00600oooo00<00000000[[`00:jl03@00:jl00`00000002^_000[[`0=000[[`030000
0000:jl002^_00D002^_00<00000000[[`00:jl02000:jl00`00000002^_000[[`0A000[[`030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000
003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool0:03oool004L0oooo00<000000?ooo`3oool0
5P3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00d002^_00<00000000[[`00:jl0
0`00:jl2000000/002^_00<00000000[[`00:jl04@00:jl00`00000005Vj001I^P02001I^P030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000
0000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo02P0oooo00170?ooo`030000003oool0oooo01H0oooo00<00000000[[`00:jl0
3@00:jl00`00000002^_000[[`0=000[[`0300000000:jl002^_008002^_00<00000000[[`00:jl0
1`00:jl01@00000002^_000[[`00:jl0000001<002^_00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0X0?ooo`00A`3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl002^_00d0
02^_00<00000000[[`00:jl03@00:jl01@00000002^_000[[`00:jl0000000X002^_00D00000000[
[`00:jl002^_0000000C000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX0
0`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX0
0`00000005Vj001I^P02001I^P030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool0
3P000000oooo0?ooo`000000V9RH0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P00000:P3o
ool004L0oooo00<000000?ooo`3oool05P3oool00`00000002^_000[[`0=000[[`0300000000:jl0
02^_00d002^_00@00000000[[`00000000002`00:jl01@00000002^_000[[`00:jl0000001<002^_
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`040?ooo`05024Q8@000000oooo0?ooo`2H
V9P00`0000000`2HV9P0oooo09RHV0030000000309RHV03oool0oooo02P0oooo001P0?ooo`030000
0000:jl002^_00d002^_00<00000000[[`00:jl03@00:jl20000014002^_00<00000000[[`00:jl0
4@00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX0
0P00FKX00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03d0oooo001P0?ooo`0300000000
:jl002^_00d002^_00<00000000[[`00:jl03000:jl30000014002^_00<00000000[[`00:jl04@00
:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00
FKX00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03d0oooo00160?ooo`030000003oool0
oooo01L0oooo00<00000000[[`00:jl03000:jl00`00000002^_000[[`0<000[[`0300000000:jl0
000000h002^_00D00000000[[`00:jl002^_0000000C000[[`0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01L0oooo0P00
000n0?ooo`00AP3oool00`000000oooo0?ooo`0G0?ooo`0300000000:jl002^_00`002^_00<00000
000[[`00:jl02`00:jl01000000002^_000[[`00000>000[[`0500000000:jl002^_000[[`000000
4`00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX0
0P00FKX00`000000oooo0?ooo`0G0?ooo`800000?P3oool004H0oooo00<000000?ooo`3oool05`3o
ool00`00000002^_000[[`0<000[[`0300000000:jl002^_00T002^_0P000003000[[`0300000000
:jl002^_00`002^_00D00000000[[`00:jl002^_0000000C000[[`0300000000FKX005Vj008005Vj
00<00000001I^P00FKX00`00FKX01@00000005Vj001I^P00FKX0000000@005Vj00<00000001I^P00
FKX00`00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0?03oool004H0oooo00<000000?ooo`3oool05`3oool00`00000002^_000[[`0<000[[`030000
0000:jl002^_00P002^_00<00000000[[`00:jl00`00:jl00`00000002^_000[[`0<000[[`050000
0000:jl002^_000[[`0000004`00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<0
05Vj00<00000001I^P00FKX00P00FKX01@00000005Vj001I^P00FKX0000000D005Vj00<00000001I
^P00FKX00P00FKX00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03`0oooo001O0?ooo`03
00000000:jl002^_00d002^_00<00000000[[`00:jl01P00:jl2000000H002^_00<00000000[[`00
:jl04000:jl00`00000002^_000[[`0A000[[`0300000000FKX005Vj008005Vj00<00000001I^P00
FKX00`00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00
FKX00P00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01L0oooo0P00000n0?ooo`00
AP3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl002^_00d002^_00<00000000[[`00:jl0
1@00:jl00`00000002^_000[[`06000[[`0300000000:jl002^_00`002^_00D00000000[[`00:jl0
02^_0000000C000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`000000
05Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0?03oool004H0oooo
00<000000?ooo`3oool05P3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00@002^_
00<00000000[[`00:jl01`00:jl00`00000002^_000[[`0<000[[`0500000000:jl002^_000[[`00
00004`00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00
FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00
FKX00P00FKX00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03`0oooo00160?ooo`030000
003oool0oooo01H0oooo00<00000000[[`00:jl03@00:jl00`00000002^_000[[`02000[[`800000
2P00:jl00`00000002^_000[[`0<000[[`0500000000:jl002^_000[[`0000004`00:jl00`000000
05Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo03`0oooo00160?ooo`030000003oool0oooo01H0oooo
00<00000000[[`00:jl03@00:jl01@00000002^_000[[`00:jl0000000`002^_00<00000000[[`00
:jl03000:jl01@00000002^_000[[`00:jl0000001<002^_00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0l0?ooo`00G`3oool00`00000002^_000[[`0=000[[`0400000000:jl002^_0000
00d002^_00<00000000[[`00:jl04000:jl00`00000002^_000[[`0A000[[`0300000000FKX005Vj
008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj
008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo
01P0oooo00<000000?ooo`3oool0?03oool005l0oooo00<00000000[[`00:jl03@00:jl3000000h0
02^_00<00000000[[`00:jl04000:jl00`00000002^_000[[`0A000[[`0300000000FKX005Vj0080
05Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj0080
05Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01P0
oooo00<000000?ooo`3oool0?03oool004H0oooo00<000000?ooo`3oool05P3oool00`00000002^_
000[[`0=000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl03000:jl01@00000002^_
000[[`00:jl0000001<002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P03
00000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P03
00000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0l0?ooo`00
AP3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl002^_00/002^_0`00000@000[[`030000
0000:jl002^_00`002^_00D00000000[[`00:jl002^_0000000C000[[`0300000000FKX005Vj0080
05Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj0080
05Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01P0
oooo00<000000?ooo`3oool0?03oool004H0oooo00<000000?ooo`3oool05P3oool00`00000002^_
000[[`0:000[[`0400000000:jl002^_0000010002^_00<00000000[[`00:jl03000:jl01@000000
02^_000[[`00:jl0000001<002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0l0?oo
o`00G`3oool00`00000002^_000[[`09000[[`0500000000:jl002^_000[[`0000004000:jl00`00
000002^_000[[`0<000[[`0500000000:jl002^_000[[`0000004`00:jl00`00000005Vj001I^P02
001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo03`0oooo001O0?ooo`0300000000:jl002^_00L002^_0P000004000[
[`0300000000:jl002^_00h002^_00<00000000[[`00:jl04000:jl00`00000002^_000[[`0A000[
[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0?03oool004H0oooo00<000000?ooo`3o
ool05P3oool00`00000002^_000[[`06000[[`0300000000:jl002^_00@002^_00<00000000[[`00
:jl03P00:jl00`00000002^_000[[`0<000[[`0500000000:jl002^_000[[`0000004`00:jl00`00
000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo03`0oooo00160?ooo`030000003oool0oooo01H0
oooo00<00000000[[`00:jl01@00:jl00`00000002^_000[[`05000[[`0300000000:jl002^_00h0
02^_00<00000000[[`00:jl03000:jl01@00000002^_000[[`00:jl0000001<002^_00<00000001I
^P00FKX00P00FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I
^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0l0?ooo`00AP3oool00`000000oooo0?ooo`0F0?ooo`03
00000000:jl002^_00<002^_0P000008000[[`0300000000:jl002^_00h002^_00<00000000[[`00
:jl03000:jl01@00000002^_000[[`00:jl0000001<002^_00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool05`3oool20000
03h0oooo00160?ooo`030000003oool0oooo01H0oooo00<00000000[[`00:jl00P00:jl00`000000
02^_000[[`08000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl03000:jl01@000000
02^_000[[`00:jl0000001<002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0l0?oo
o`00G`3oool00`00000002^_000[[`02000000/002^_00<00000000[[`00:jl03P00:jl00`000000
02^_000[[`0@000[[`0300000000:jl002^_014002^_00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0l0?ooo`00AP3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl0000000d002^_
00<00000000[[`00:jl03P00:jl00`00000002^_000[[`0@000[[`0300000000:jl002^_010002^_
10000002001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo03`0oooo00160?ooo`030000003oool0oooo01H0oooo0P00
000>000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl03000:jl01@00000002^_000[
[`00:jl00000014002^_00<00000000[[`0000000P00FKX4000000@005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03`0oooo00160?ooo`030000003o
ool0oooo01H0oooo00<00000000[[`00:jl03@00:jl00`00000002^_000[[`0>000[[`0300000000
:jl002^_00`002^_00D00000000[[`00:jl002^_0000000?000[[`8000000P00:jl00`00000005Vj
001I^P02001I^P0300000000FKX0000000@000001000FKX00`00000005Vj001I^P02001I^P030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo03`0oooo00160?ooo`030000003oool0oooo01H0oooo00<00000000[[`00:jl03@00
:jl00`00000002^_000[[`0>000[[`0300000000:jl002^_00`002^_00D00000000[[`00:jl002^_
0000000>000[[`0300000000:jl002^_008002^_00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P03001I^P@0000000<005Vj0000000000000`00FKX00`00000005Vj001I^P03001I^P050000
0000FKX005Vj001I^P0000006P3oool00`000000oooo0?ooo`0l0?ooo`00G`3oool00`00000002^_
000[[`0=000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl04000:jl00`00000002^_
000[[`0:000[[`8000001@00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj
00@00000001I^P00FKX005Vj1@0000000`00FKX00000001I^P04001I^P0300000000FKX005Vj0080
05Vj00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0l0?ooo`00G`3oool00`00000002^_
000[[`0=000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl04000:jl00`00000002^_
000[[`08000[[`8000001`00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj
00<00000001I^P00FKX00P00FKX01000000005Vj001I^P00FKX50000008005Vj00<00000001I^P00
FKX00P00FKX00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03`0oooo00160?ooo`030000
003oool0oooo01H0oooo00<00000000[[`00:jl03@00:jl00`00000002^_000[[`0>000[[`030000
0000:jl002^_00`002^_00D00000000[[`00:jl002^_00000009000[[`0300000000:jl002^_00L0
02^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj0080
05Vj00<00000001I^P00FKX00P00FKX01000000005Vj001I^P00FKX50000008005Vj00<000000?oo
o`3oool05`3oool2000003d0oooo00160?ooo`030000003oool0oooo01H0oooo00<00000000[[`00
:jl03@00:jl00`00000002^_000[[`0>000[[`0300000000:jl002^_00`002^_00D00000000[[`00
:jl002^_00000007000[[`8000002P00:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj
00<005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj
00<005Vj00<00000001I^P00FKX00`00000I0?ooo`030000003oool0oooo01<0oooo1P00000S0?oo
o`00AP3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl002^_00d002^_00<00000000[[`00
:jl03P00:jl00`00000002^_000[[`0<000[[`0500000000:jl002^_000[[`0000001P00:jl00`00
000002^_000[[`0:000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00
000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00
000005Vj001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool01P2Y
ZJT0<S8b0?ooo`3oool0k^k^038b<R<0oooo001O0?ooo`0300000000:jl002^_00d002^_00<00000
000[[`00:jl03P00:jl00`00000002^_000[[`0<000[[`0500000000:jl002^_000[[`0000001000
:jl2000000d002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P0300000000
FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P0300000000
FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0C0?ooo`0306IVIP1g
MgL0oooo02D0oooo001O0?ooo`0300000000:jl002^_00d002^_00<00000000[[`00:jl03P00:jl0
0`00000002^_000[[`0@000[[`0500000000:jl002^_000[[`0000003`00:jl00`00000005Vj001I
^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo01<0oooo00<0k^k^024Q8@3<c<`09@3oool004D0oooo00<00000
0?ooo`3oool05`3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00h002^_00<00000
000[[`00:jl03000:jl01P00000002^_000[[`00:jl00000000[[`8000004000:jl00`00000005Vj
001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo01@0oooo00<0c<c<024Q8@3^k^h0903oool004D0oooo00<0
00000?ooo`3oool05`3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00h002^_00<0
0000000[[`00:jl03000:jl01000000002^_000[[`00:jl20000018002^_00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0
5`3oool2000001L0oooo00<0MgMg06IVIP3oool08`3oool004D0oooo00<000000?ooo`3oool05`3o
ool00`00000002^_000[[`0=000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl03000
:jl00`00000002^_000[[`02000001<002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P03001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0B0?ooo`06038b<P3^k^h0oooo0?ooo`0b<S80ZJVY8`3oool004D0oooo00<000000?ooo`3oool0
5`3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl0
3000:jl300000003000[[`00000002^_018002^_00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P03001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0B0?ooo`H000008`3oool005l0oooo00<00000000[[`00:jl03@00:jl00`00000002^_000[
[`0>000[[`0300000000:jl002^_00`002^_00D00000000[[`00:jl002^_0000000C000[[`030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000
003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool004D0oooo00<000000?ooo`3oool05`3o
ool00`00000002^_000[[`0=000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl02P00
:jl2000000@002^_00<00000000[[`00:jl04P00:jl01@00000005Vj001I^P00FKX0000000D005Vj
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj
00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03/0oooo
00150?ooo`030000003oool0oooo01L0oooo00<00000000[[`00:jl03@00:jl00`00000002^_000[
[`0>000[[`0300000000:jl002^_00T002^_00@00000000[[`00:jl000000`00:jl00`00000002^_
000[[`0B000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj
001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool004D0oooo00<0
00000?ooo`3oool05`3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00h002^_00<0
0000000[[`00:jl01`00:jl2000000<002^_00D00000000[[`00:jl002^_0000000D000[[`030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000
003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool004D0oooo00<000000?ooo`3oool05`3o
ool00`00000002^_000[[`0=000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl01P00
:jl00`00000002^_000[[`03000[[`0500000000:jl002^_000[[`0000005000:jl00`00000005Vj
001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo03/0oooo001O0?ooo`0300000000:jl002^_00d002^_00<0
0000000[[`00:jl03P00:jl00`00000002^_000[[`04000[[`8000002P00:jl00`00000002^_000[
[`0B000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I
^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool005l0oooo00<00000
000[[`00:jl03@00:jl00`00000002^_000[[`0>000[[`0300000000:jl002^_008002^_0P00000<
000[[`0300000000:jl002^_018002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03
001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0k
0?ooo`00A@3oool00`000000oooo0?ooo`0G0?ooo`0300000000:jl002^_00d002^_00<00000000[
[`00:jl03P00:jl01@00000002^_000[[`00:jl0000000X002^_00D00000000[[`00:jl002^_0000
000D000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I
^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool004D0oooo00<00000
0?ooo`3oool05`3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00h002^_00@00000
000[[`00000000002`00:jl01@00000002^_000[[`00:jl0000001@002^_00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0k0?ooo`00A@3oool00`000000oooo0?ooo`0G0?ooo`0300000000
:jl002^_00d002^_00<00000000[[`00:jl03P00:jl2000000d002^_00D00000000[[`00:jl002^_
0000000D000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj
001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool005l0oooo00<0
0000000[[`00:jl03@00:jl00`00000002^_000[[`0=000[[`8000003P00:jl01@00000002^_000[
[`00:jl0000001@002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P030000
0000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0k0?ooo`00GP3o
ool00`00000002^_000[[`0>000[[`0300000000:jl002^_00`002^_00<00000000[[`0000004P00
:jl00`00000002^_000[[`0B000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00
FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0>`3o
ool004D0oooo00<000000?ooo`3oool05P3oool00`00000002^_000[[`0>000[[`0300000000:jl0
02^_00X002^_0P000002000[[`0300000000:jl002^_00`002^_00D00000000[[`00:jl002^_0000
000D000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I
^P02001I^P030000003oool0oooo01L0oooo0P00000m0?ooo`00A@3oool00`000000oooo0?ooo`0F
0?ooo`0300000000:jl002^_00h002^_00<00000000[[`00:jl02000:jl2000000@002^_00<00000
000[[`00:jl03000:jl01@00000002^_000[[`00:jl0000001@002^_00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0k0?ooo`00A@3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl0
02^_00h002^_00<00000000[[`00:jl01`00:jl00`00000002^_000[[`04000[[`0300000000:jl0
02^_00`002^_00D00000000[[`00:jl002^_0000000D000[[`0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0>`3oool004D0oooo00<000000?ooo`3oool05P3oool00`00000002^_000[[`0>
000[[`0300000000:jl002^_00D002^_0P000007000[[`0300000000:jl002^_00`002^_00D00000
000[[`00:jl002^_0000000D000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00
FKX01@00000005Vj001I^P00FKX0000000@005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj
001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool005h0oooo00<0
0000000[[`00:jl03P00:jl00`00000002^_000[[`03000[[`8000002@00:jl00`00000002^_000[
[`0@000[[`0300000000:jl002^_018002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P03001I^P0300000000FKX005Vj008005Vj00D00000001I^P00FKX005Vj00000005001I^P030000
0000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0k0?ooo`00A@3o
ool00`000000oooo0?ooo`0F0?ooo`0300000000:jl002^_00h002^_00<00000000[[`00:jl00P00
:jl00`00000002^_000[[`09000[[`0300000000:jl002^_010002^_00<00000000[[`00:jl04P00
:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03/0oooo00150?ooo`030000003oool0
oooo01H0oooo00<00000000[[`00:jl03P00:jl00`00000002^_000[[`02000000`002^_00<00000
000[[`00:jl03000:jl01@00000002^_000[[`00:jl0000001@002^_00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603o
ool2000003`0oooo00150?ooo`030000003oool0oooo01H0oooo00<00000000[[`00:jl03P00:jl0
0`00000002^_0000000>000[[`0300000000:jl002^_00`002^_00D00000000[[`00:jl002^_0000
000D000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I
^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I
^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0>`3oool004D0oooo00<00000
0?ooo`3oool05P3oool00`00000002^_000[[`0>000[[`8000003`00:jl00`00000002^_000[[`0<
000[[`0500000000:jl002^_000[[`0000005000:jl00`00000005Vj001I^P02001I^P0300000000
FKX005Vj00<005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000
FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo03X0oooo001N0?ooo`0300000000:jl002^_00`002^_0`00000@000[[`0300000000:jl0
02^_010002^_00<00000000[[`00:jl04P00:jl00`00000005Vj001I^P02001I^P0300000000FKX0
05Vj00<005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX0
05Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo03X0oooo001N0?ooo`0300000000:jl002^_00/002^_00@00000000[[`00:jl000004000:jl0
0`00000002^_000[[`0@000[[`0300000000:jl002^_018002^_00<00000001I^P00FKX00P00FKX0
0`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX0
0`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0j0?ooo`00A@3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl002^_
00T002^_0P000003000[[`0300000000:jl002^_00h002^_00<00000000[[`00:jl03000:jl01@00
000002^_000[[`00:jl0000001@002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0j
0?ooo`00A@3oool00`000000oooo0?ooo`0F0?ooo`0300000000:jl002^_00P002^_00<00000000[
[`00:jl00`00:jl00`00000002^_000[[`0>000[[`0300000000:jl002^_00`002^_00D00000000[
[`00:jl002^_0000000D000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX0
0`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX0
0`00000005Vj001I^P02001I^P030000003oool0oooo01T0oooo00<000000?ooo`3oool0>P3oool0
04@0oooo00<000000?ooo`3oool05`3oool00`00000002^_000[[`06000[[`8000001@00:jl00`00
000002^_000[[`0?000[[`0300000000:jl002^_00`002^_00D00000000[[`00:jl002^_0000000D
000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX01@00000005Vj001I^P00
FKX0000001/0oooo00<000000?ooo`3oool0>P3oool004@0oooo00<000000?ooo`3oool05`3oool0
0`00000002^_000[[`04000[[`8000001`00:jl00`00000002^_000[[`0?000[[`0300000000:jl0
02^_00`002^_00D00000000[[`00:jl002^_0000000D000[[`0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<0
0000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0>P3oool005h0oooo00<00000000[[`00:jl00`00:jl00`00000002^_000[[`07
000[[`0300000000:jl002^_00l002^_00<00000000[[`00:jl04000:jl00`00000002^_000[[`0B
000[[`0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02
001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02
001I^P030000003oool0oooo01H0oooo0`0000040?ooo`@0000000<0^[Zj0?ooo`2HV9P00`000000
0`2HV9P0oooo09RHV0030000000309RHV03oool0oooo02D0oooo00140?ooo`030000003oool0oooo
01L0oooo00@00000000[[`00:jl002^_0P00000:000[[`0300000000:jl002^_00l002^_00<00000
000[[`00:jl03000:jl01@00000002^_000[[`00:jl0000001@002^_00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00
FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`020?ooo`0A0<c<c03^k^h0oooo0<c<c01EEED0oooo0000002HV9P0oooo
09RHV0000000oooo0000002HV9P0oooo09RHV00000009`3oool004@0oooo00<000000?ooo`3oool0
5`3oool01000000002^_00000000000<000[[`0300000000:jl002^_00l002^_00<00000000[[`00
:jl03000:jl01@00000002^_000[[`00:jl0000001@002^_00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`030?ooo`030<c<c03^k^h0oooo0080oooo00L000000?ooo`3oool0oooo0000003o
ool0000000<0oooo00<000000?ooo`3oool09@3oool004@0oooo00<000000?ooo`3oool05`3oool2
000000h002^_00<00000000[[`00:jl03`00:jl00`00000002^_000[[`0<000[[`0500000000:jl0
02^_000[[`0000005000:jl00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<0
0000001I^P00FKX00P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<005Vj00<0
0000001I^P00FKX00P00FKX00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0oooo00D0
ZJVY0>k^kP3oool0oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
9@3oool004@0oooo00<000000?ooo`3oool05`3oool00`00000002^_000[[`0=000[[`0300000000
:jl002^_00l002^_00<00000000[[`00:jl03000:jl01@00000002^_000[[`00:jl0000001@002^_
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj
00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`050=gMg@1VIVH0oooo0?ooo`00
00000`3oool00`000000oooo000000030?ooo`030000003oool0oooo02D0oooo001N0?ooo`030000
0000:jl002^_00d002^_00<00000000[[`00:jl03`00:jl00`00000002^_000[[`0@000[[`030000
0000:jl002^_018002^_00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P030000
0000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P030000
0000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`0407Mg
M`3oool0oooo00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool09@3oool005h0oooo00<00000000[[`00:jl03@00:jl00`00000002^_000[[`0?000[
[`0300000000:jl002^_00/002^_1P00000D000[[`D005Vj00<00000001I^P00FKX00`00FKX00`00
000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00
000005Vj001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool01000
0000V9RH09RHV00000020?ooo`0;0000002HV9P0oooo09RHV0000000oooo0000002HV9P0oooo09RH
V00000009`3oool004@0oooo00<000000?ooo`3oool05`3oool00`00000002^_000[[`0=000[[`03
00000000:jl002^_00l002^_00<00000000[[`00:jl02@00:jl200000003000XZ`00000005Vj0080
05Vj1P000003000[[`0300000000:jl002^_00T002^_1@00FKX00`00000005Vj001I^P03001I^P03
00000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P03
00000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`020?ooo`04
09RHV0000000000009RHV080oooo00L0V9RH000000000000000009RHV03oool0V9RH00<0000000<0
V9RH0?ooo`3oool09@3oool004@0oooo00<000000?ooo`3oool05`3oool00`00000002^_000[[`0=
000[[`0300000000:jl002^_00l002^_00<00000000[[`00:jl01`00:jl2000000<002R[00<00000
001I^P00FKX01`00FKX7000000P002^_1@00FKX00`00000005Vj001I^P03001I^P0300000000FKX0
05Vj008005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj001I^P03001I^P0300000000FKX0
05Vj008005Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0j0?ooo`00A03oool00`00
0000oooo0?ooo`0G0?ooo`0300000000:jl002^_00d002^_00<00000000[[`00:jl03`00:jl00`00
000002^_000[[`05000[[`8000001@00::/00`00000005Vj001I^P09001I^P0300000000FKX005Vj
008005Vj1P000002000[[`D005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I
^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I
^P030000003oool0oooo01P0oooo00<000000?ooo`3oool0>P3oool005h0oooo00<00000000[[`00
:jl03@00:jl00`00000002^_000[[`0?000[[`0300000000:jl002^_00@002^_00<00000000XZ`00
::/01@00::/00`00000005Vj001I^P09001I^P0300000000FKX005Vj00P005Vj1P0000000`00FKX0
0000001I^P04001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX00P00FKX00`000000
05Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0j0?ooo`00GP3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00l002^_
00<00000000[[`00:jl00P00:jl2000000P002R[00<00000001I^P00FKX02@00FKX00`00000005Vj
001I^P0:001I^P0400000000FKX005Vj001I^PD000000P00FKX00`00000005Vj001I^P02001I^P03
00000000FKX005Vj008005Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P02001I^P03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0>P3oool004@0oooo00<000000?ooo`3oool0
5`3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00l002^_00<00000000[[`00:jl0
0P00000:000XZ`0300000000FKX005Vj00T005Vj00<00000001I^P00FKX02P00FKX2000000<005Vj
00@00000001I^P00FKX005Vj1@000002001I^P0300000000FKX005Vj008005Vj00<00000001I^P00
FKX00`00FKX00`00000005Vj001I^P02001I^P030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0>P3oool004@0oooo00<000000?ooo`3oool05`3oool00`00000002^_000[[`0=000[[`030000
0000:jl002^_00l002^_0`00000<000XZ`0300000000FKX005Vj00T005Vj00<00000001I^P00FKX0
2P00FKX00`00000005Vj00000002001I^P0300000000FKX005Vj00<005Vj00<00000001I^P00FKX0
1P0000000`00FKX00000001I^P04001I^P0300000000FKX005Vj008005Vj00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0j0?ooo`00A03oool00`000000oooo0?ooo`0G0?ooo`0300000000
:jl002^_00d002^_00<00000000[[`00:jl03P00:jl2000000h002R[00<00000001I^P00FKX02@00
FKX00`00000005Vj001I^P0:001I^P0500000000FKX005Vj00000000FKX00`000003001I^P030000
0000FKX005Vj008005Vj00@00000001I^P00FKX005Vj1@000002001I^P0300000000FKX005Vj0080
05Vj00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0j0?ooo`00A03oool00`000000oooo
0?ooo`0G0?ooo`0300000000:jl002^_00d002^_00<00000000[[`00:jl03000:jl20000010002R[
00<00000001I^P00FKX02@00FKX00`00000005Vj001I^P0:001I^P0400000000FKX005Vj001I^P80
00001@00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj008005Vj00@00000001I^P00
FKX005Vj1@000002001I^P030000003oool0oooo01L0oooo0P00000l0?ooo`00GP3oool00`000000
02^_000[[`0=000[[`0300000000:jl002^_00X002^_0P00000B000XZ`0300000000FKX005Vj00T0
05Vj00<00000001I^P00FKX02P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00<0
05Vj00<00000001I^P00FKX00P00FKX30000008005Vj00@00000001I^P00000000000P00FKX00`00
000005Vj001I^P06000001L0oooo00<000000?ooo`3oool0>P3oool004@0oooo00<000000?ooo`3o
ool05`3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00T002^_00<00000000XZ`00
::/04P00::/00`00000005Vj001I^P09001I^P0300000000FKX005Vj00X005Vj00<00000001I^P00
FKX00P00FKX00`00000005Vj001I^P03001I^P0300000000FKX005Vj008005Vj00<00000001I^P00
FKX00P00FKX00`00000005Vj001I^P03001I^P0600000000FKX005Vj00000000FKX000000`00FKX6
00000140oooo0P00000k0?ooo`00A03oool00`000000oooo0?ooo`0G0?ooo`0300000000:jl002^_
00d002^_00<00000000[[`00:jl01`00:jl3000001<002R[1@000008001I^P0300000000FKX005Vj
00X005Vj00L00000001I^P00FKX005Vj00000000FKX0000000<005Vj00<00000001I^P00FKX00`00
FKX2000000@005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj00000002001I^P0300000000
FKX005Vj00L005Vj1@00000<0?ooo`800000>`3oool004@0oooo00<000000?ooo`3oool05`3oool0
0`00000002^_000[[`0=000[[`0300000000:jl002^_00D002^_0P000002000XZ`0300000000::/0
02R[00l002R[0P0000000`00::/00000001I^P02001I^PH000000P00FKX00`00000005Vj001I^P0:
001I^P0400000000FKX005Vj000000<005Vj00@00000001I^P00FKX000001@00FKX200000005001I
^P00000005Vj001I^P0000001000FKX2000000<005Vj00<00000001I^P00FKX02@00FKX00`000000
05Vj001I^P06000000H0oooo00<000000?ooo`3oool0>P3oool004@0oooo00<000000?ooo`3oool0
5`3oool00`00000002^_000[[`0=000[[`0300000000:jl002^_00<002^_0P000004000XZ`030000
0000::/002R[00d002R[0P000003000XZ`0300000000FKX005Vj00L005Vj1`000008001I^P030000
0000FKX0000000D005Vj00<00000001I^P0000001@00FKX2000000@005Vj00<00000001I^P00FKX0
0P00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00T005Vj00<00000001I^P00FKX0
1P00FKX3000000@0oooo00<000000?ooo`3oool0>@3oool005h0oooo00<00000000[[`00:jl03@00
:jl01000000002^_000[[`00:jl2000000H002R[00<00000000XZ`00::/02`00::/2000000D002R[
00<00000001I^P00FKX02@00FKX00`00000005Vj001I^P02001I^PH000000P00FKX2000000H005Vj
00<00000001I^P0000001@00FKX2000000@005Vj00<00000001I^P00FKX00P00FKX00`00000005Vj
001I^P02001I^P0300000000FKX005Vj00T005Vj00<00000001I^P00FKX02000FKX00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03T0oooo001N0?ooo`0300000000:jl002^_00d002^_00@0
0000000[[`00000000002000::/00`00000002R[000XZ`0:000XZ`0300000000::/002R[00D002R[
00<00000001I^P00FKX02@00FKX00`00000005Vj001I^P08001I^P<000002000FKX2000000@005Vj
0`000004001I^P0700000000FKX005Vj001I^P00000005Vj00000003001I^P0300000000FKX005Vj
00T005Vj00<00000001I^P00FKX02000FKX00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03T0oooo00140?ooo`030000003oool0oooo01L0oooo00<00000000[[`00:jl03@00:jl2000000X0
02R[00<00000000XZ`00::/02000::/2000000P002R[00<00000001I^P00FKX02@00FKX00`000000
05Vj001I^P0:001I^P0300000000FKX005Vj00L005Vj00<00000001I^P00FKX00P00FKX3000000D0
05Vj00<00000001I^P0000000`00FKX01000000005Vj001I^P00000;001I^P0300000000FKX005Vj
00P005Vj00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0i0?ooo`00A03oool00`000000
oooo0?ooo`0G0?ooo`0300000000:jl002^_00`002^_00<00000000XZ`00::/02P00::/00`000000
02R[000XZ`06000XZ`8000002P00::/00`00000005Vj001I^P09001I^P0300000000FKX005Vj00X0
05Vj00<00000001I^P00FKX01`00FKX00`00000005Vj001I^P02001I^P<000001@00FKX2000000@0
05Vj00@00000001I^P00FKX000002`00FKX00`00000005Vj001I^P08001I^P030000003oool0oooo
0080oooo00<000000?ooo`3oool0>@3oool004@0oooo00<000000?ooo`3oool05`3oool00`000000
02^_000[[`0:000[[`8000003@00::/00`00000002R[000XZ`04000XZ`8000003000::/00`000000
05Vj001I^P09001I^P0300000000FKX005Vj00X005Vj00<00000001I^P00FKX01P00FKX00`000000
05Vj00000003001I^P<000001@00FKX00`00000005Vj001I^P04001I^P0300000000FKX0000000/0
05Vj00<00000001I^P00FKX02000FKX00`000000oooo0?ooo`020?ooo`030000003oool0oooo03T0
oooo001N0?ooo`0300000000:jl002^_00P002^_0P00000?000XZ`0300000000::/002R[008002R[
0P00000>000XZ`0300000000FKX005Vj00T005Vj00<00000001I^P00FKX02P00FKX00`00000005Vj
001I^P05001I^P0500000000FKX005Vj001I^P0000000P00FKX3000000@005Vj0P000006001I^P03
00000000FKX0000000/005Vj00<00000001I^P00FKX02000FKX00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03T0oooo001N0?ooo`0300000000:jl002^_00H002^_0P00000A000XZ`030000
0000::/002R[008000004000::/00`00000005Vj001I^P0:001I^P0300000000FKX005Vj00T005Vj
00<00000001I^P00FKX01000FKX00`00000005Vj001I^P03001I^P0600000000FKX0000000000000
FKX000000P00FKX01000000005Vj001I^P000006001I^P8000002`00FKX00`00000005Vj001I^P08
001I^P030000003oool0oooo0080oooo00<000000?ooo`3oool0>@3oool004<0oooo00<000000?oo
o`3oool05`3oool00`00000002^_000[[`05000[[`80000000<002R[00000000::/04000::/30000
018002R[00<00000001I^P00FKX02P00FKX00`00000005Vj001I^P09001I^P0300000000FKX005Vj
00<005Vj00<00000001I^P00FKX01@00FKX300000004001I^P00000005Vj000000@005Vj00<00000
001I^P00FKX01000FKX4000000P005Vj00<00000001I^P00FKX02000FKX00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03T0oooo00130?ooo`030000003oool0oooo01L0oooo00<00000000[
[`00:jl01000:jl01@00000002R[000XZ`00::/00000014002R[00<00000000XZ`00::/04P00::/0
0`00000005Vj001I^P0:001I^P0300000000FKX005Vj00T005Vj00<00000001I^P00FKX00P00FKX0
0`00000005Vj001I^P07001I^P80000000<005Vj0000000000001@00FKX00`00000005Vj001I^P04
001I^P0400000000FKX005Vj001I^PH000000P00FKX00`00000005Vj001I^P08001I^P030000003o
ool0oooo0080oooo00<000000?ooo`3oool0>@3oool004<0oooo00<000000?ooo`3oool05`3oool0
0`00000002^_000[[`02000[[`8000001000::/00`00000002R[000XZ`0=000XZ`<000005000::/0
0`00000005Vj001I^P0:001I^P0300000000FKX005Vj00T005Vj00<00000001I^P00FKX00P00FKX0
0`00000005Vj001I^P07001I^P@000001`00FKX00`00000005Vj001I^P03001I^P0300000000FKX0
05Vj00L005Vj1P000008001I^P050000003oool0oooo0?ooo`000000>`3oool004<0oooo00<00000
0?ooo`3oool05`3oool00`00000002^_000[[`02000000H002R[00<00000000XZ`00::/02`00::/2
0000008002R[00<00000000XZ`00::/04@00::/5000000T005Vj00<00000001I^P00FKX02@00FKX0
1@00000005Vj001I^P00FKX0000000T005Vj00D00000001I^P00000005Vj00000008001I^P030000
0000FKX005Vj008005Vj00<00000001I^P00FKX02@00FKX01000000005Vj001I^P00FKX600000080
05Vj00<000000?ooo`3oool00P00000k0?ooo`00G@3oool3000000P002R[00<00000000XZ`00::/0
2@00::/2000000@002R[00<00000000XZ`00::/03`00::/200000003000XZ`00000005Vj008005Vj
1P000003001I^P0300000000FKX005Vj00T005Vj00@00000001I^P00FKX000002@00FKX010000000
05Vj001I^P000002001I^P0300000000FKX005Vj00D005Vj00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P09001I^P0300000000FKX005Vj00L005Vj0`0000030?ooo`030000003oool0oooo
03T0oooo00130?ooo`030000003oool0oooo01H0oooo0P00000:000XZ`0300000000::/002R[00L0
02R[0P000006000XZ`0300000000::/002R[00d002R[0P000003000XZ`0300000000FKX005Vj00L0
05Vj1`000008001I^P0300000000FKX0000000T005Vj00D00000001I^P00FKX005Vj00000003001I
^P0300000000FKX005Vj00D005Vj00D00000001I^P00FKX005Vj0000000;001I^P0300000000FKX0
05Vj00T005Vj00D000000?ooo`3oool0oooo0000000k0?ooo`00@`3oool00`000000oooo0?ooo`0E
0?ooo`0300000000::/002R[00X002R[00<00000000XZ`00::/01@00::/2000000P002R[00<00000
000XZ`00::/02`00::/2000000D002R[00<00000001I^P00FKX02P00FKX01000000005Vj001I^P00
FKX60000008005Vj0P000009001I^P0300000000FKX005Vj008005Vj00D00000001I^P00FKX005Vj
00000008001I^P0400000000FKX005Vj000000/005Vj00<00000001I^P00FKX02@00FKX01@000000
oooo0?ooo`3oool0000003/0oooo00130?ooo`030000003oool0oooo01<0oooo0P00000=000XZ`03
00000000::/002R[00<002R[0P00000:000XZ`0300000000::/002R[00T002R[0P000007000XZ`03
00000000FKX005Vj00X005Vj00<00000001I^P00FKX01`00FKX3000000T005Vj00<00000001I^P00
FKX00`00FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00D005Vj00D00000001I^P00
FKX005Vj0000000:001I^P0300000000FKX005Vj00T005Vj00D000000?ooo`3oool0oooo0000000k
0?ooo`00@`3oool00`000000oooo0?ooo`0A0?ooo`8000003`00::/00`00000002R[000XZ`02000X
Z`0300000000::/002R[00X002R[00<00000000XZ`00::/01`00::/2000000T002R[00<00000001I
^P00FKX02P00FKX00`00000005Vj001I^P09001I^P0300000000FKX005Vj00L005Vj00<00000001I
^P00FKX01000FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00D005Vj00@00000001I
^P00FKX000002P00FKX00`00000005Vj001I^P09001I^P050000003oool0oooo0?ooo`000000>`3o
ool005D0oooo0P00000A000XZ`0300000000::/002R[008000003@00::/00`00000002R[000XZ`05
000XZ`8000002`00::/00`00000005Vj001I^P0:001I^P0300000000FKX005Vj00T005Vj00<00000
001I^P00FKX01P00FKX00`00000005Vj001I^P05001I^P0300000000FKX005Vj008005Vj00<00000
001I^P00FKX01P00FKX00`00000005Vj0000000;001I^P0300000000FKX005Vj00P005Vj00D00000
0?ooo`3oool0oooo0000000k0?ooo`00D`3oool200000003000XZ`00000002R[010002R[0`00000?
000XZ`0300000000::/002R[00<002R[0P00000=000XZ`0300000000FKX005Vj00X005Vj00<00000
001I^P00FKX02@00FKX00`00000005Vj001I^P05001I^P0300000000FKX005Vj00H005Vj00<00000
001I^P00FKX00`00FKX00`00000005Vj001I^P05001I^P0300000000FKX0000000/005Vj00<00000
001I^P00FKX02000FKX01@000000oooo0?ooo`3oool0000003/0oooo00130?ooo`030000003oool0
oooo00`0oooo00D00000000XZ`00::/002R[0000000@000XZ`8000004@00::/01000000002R[000X
Z`00::/2000000l002R[00<00000001I^P00FKX02P00FKX00`00000005Vj001I^P09001I^P030000
0000FKX005Vj00@005Vj00<00000001I^P00FKX01`00FKX00`00000005Vj001I^P04001I^P030000
0000FKX005Vj00D005Vj0P00000;001I^P0300000000FKX005Vj00P005Vj00D000000?ooo`3oool0
oooo0000000k0?ooo`00@`3oool00`000000oooo0?ooo`0:0?ooo`8000001000::/00`00000002R[
000XZ`0<000XZ`80000000<002R[00000000::/04000::/01000000002R[00000000000A000XZ`03
00000000FKX005Vj00X005Vj00<00000001I^P00FKX02@00FKX00`00000005Vj001I^P03001I^P03
00000000FKX005Vj00P005Vj00<00000001I^P00FKX01000FKX00`00000005Vj001I^P06001I^P@0
00002000FKX00`00000005Vj001I^P08001I^P050000003oool0oooo0?ooo`000000>`3oool004<0
oooo00<000000?ooo`3oool0203oool2000000H002R[00<00000000XZ`00::/02P00::/2000000<0
02R[00<00000000XZ`00::/03`00::/2000001<002R[00<00000001I^P00FKX02P00FKX00`000000
05Vj001I^P09001I^P0300000000FKX005Vj008005Vj00<00000001I^P00FKX02000FKX3000000H0
05Vj00<00000001I^P00FKX01@00FKX01000000005Vj001I^P00FKX60000008005Vj00<00000001I
^P00FKX02000FKX01@000000oooo0?ooo`3oool0000003/0oooo001<0?ooo`8000002000::/00`00
000002R[000XZ`08000XZ`8000001@00::/00`00000002R[000XZ`0=000XZ`<000005000::/00`00
000005Vj001I^P0:001I^P0300000000FKX005Vj00T005Vj00<00000001I^P00FKX00P00FKX00`00
000005Vj001I^P07001I^P0400000000FKX00000000000L005Vj00<00000001I^P00FKX01000FKX0
0`00000005Vj001I^P07001I^PD000002000FKX01@000000oooo0?ooo`3oool0000003/0oooo001:
0?ooo`8000002P00::/00`00000002R[000XZ`06000XZ`8000001`00::/00`00000002R[000XZ`0;
000XZ`8000000P00::/00`00000002R[000XZ`0A000XZ`D000002@00FKX00`00000005Vj001I^P09
001I^P0500000000FKX005Vj001I^P0000002@00FKX01P00000005Vj001I^P00000005Vj000000L0
05Vj00<00000001I^P00FKX00`00FKX00`00000005Vj001I^P09001I^P0300000000FKX005Vj00H0
00000P00FKX01@000000oooo0?ooo`3oool0000003/0oooo00130?ooo`030000003oool0oooo00<0
oooo00<00000000XZ`00::/02P00::/00`00000002R[000XZ`05000XZ`0300000000::/002R[00L0
02R[00<00000000XZ`00::/02@00::/2000000@002R[00<00000000XZ`00::/03`00::/200000003
001eo`00000007Go008007Go1P000003001I^P0300000000FKX005Vj00T005Vj00@00000001I^P00
FKX000002@00FKX01@00000005Vj001I^P00FKX00000008005Vj00<00000001I^P00FKX01000FKX0
0`00000005Vj001I^P03001I^P0300000000FKX005Vj00T005Vj00<00000001I^P00FKX01P00FKX4
00000080oooo0P00000j0?ooo`00@`3oool010000000oooo0?ooo`3oool2000000d002R[00<00000
000XZ`00::/00`00::/2000000T002R[00<00000000XZ`00::/02000::/2000000H002R[00<00000
000XZ`00::/03@00::/2000000<007Go00<00000001eo`00MOl01`00MOl7000000P005Vj00<00000
001I^P0000002P00FKX01@00000005Vj001I^P00FKX00000008005Vj00<00000001I^P00FKX01@00
FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj00T005Vj00<00000001I^P00FKX02000
FKX010000000oooo0?ooo`3oool2000003X0oooo00130?ooo`040000003oool0oooo000000l002R[
00@00000000XZ`00::/002R[0P00000;000XZ`0300000000::/002R[00H002R[0P000008000XZ`03
00000000::/002R[00/002R[0P000005001eo`0300000000MOl007Go00L007Go0P000005001eo`H0
00000P00FKX2000000X005Vj00<00000001I^P00FKX00P00FKX01@00000005Vj001I^P00FKX00000
00L005Vj00D00000001I^P00FKX005Vj0000000;001I^P0300000000FKX005Vj00P005Vj00D00000
0?ooo`3oool0oooo0000000k0?ooo`00@`3oool010000000oooo0?ooo`00000?000XZ`0400000000
::/00000000000d002R[00<00000000XZ`00::/01000::/2000000X002R[00<00000000XZ`00::/0
2@00::/2000000L007Go0P000006001eo`8000003@00MOl5000000P005Vj00<00000001I^P00FKX0
0`00FKX01@00000005Vj001I^P00FKX0000000L005Vj00D00000001I^P00FKX005Vj0000000;001I
^P0300000000FKX005Vj00P005Vj00@000000?ooo`3oool0oooo0P00000j0?ooo`00AP3oool00`00
000002R[000XZ`0=000XZ`8000003`00::/00`00000002R[000XZ`02000XZ`8000003000::/00`00
000002R[000XZ`06000XZ`<000001P00MOl2000000D007Go1000000>001eo`8000001000MOl50000
008005Vj00<00000001I^P00FKX01000FKX00`00000005Vj001I^P02001I^P0300000000FKX005Vj
00D005Vj00@00000001I^P00FKX000002`00FKX00`00000005Vj001I^P09001I^P050000003oool0
oooo0?ooo`000000>P3oool004<0oooo00@000000?ooo`3oool000003@00::/30000010002R[00<0
0000000XZ`00::/00P00000>000XZ`0300000000::/002R[00@002R[0P000007001eo`8000001P00
MOl2000000@007Go10000002001eo`8000000`00MOl2000000/007Go1P000003001I^P0300000000
FKX005Vj00<005Vj00<00000001I^P00FKX01@00FKX00`00000005Vj0000000;001I^P0300000000
FKX005Vj00T005Vj00D000000?ooo`3oool0oooo0000000j0?ooo`00@`3oool010000000oooo0?oo
o`00000;000XZ`8000000P00::/00`00000002R[000XZ`0>000XZ`<000004000::/00`00000002R[
000XZ`02000XZ`8000001P00MOl2000000L007Go0P00000>001eo`D000002000MOl3000000H007Go
200000000`00FKX00000001I^P06001I^P0300000000FKX0000000/005Vj00<00000001I^P00FKX0
2@00FKX01@000000oooo0?ooo`3oool0000003X0oooo00130?ooo`040000003oool0oooo000000T0
02R[0P000004000XZ`0300000000::/002R[00d002R[0P00000B000XZ`0300000000::/002R[0080
00001`00MOl00`00000007Go001eo`05001eo`8000003P00MOl3000000@007Go00<00000001eo`00
MOl01@00000:001eo`0300000000MOl007Go00@007Go20000002001I^P8000002`00FKX00`000000
05Vj001I^P09001I^P050000003oool0oooo0?ooo`000000>P3oool004<0oooo00@000000?ooo`3o
ool000001`00::/2000000H002R[00<00000000XZ`00::/02`00::/200000003000XZ`00000002R[
014002R[0`00000?001eo`8000003P00MOl3000000X007Go0P000002001eo`@000000`00MOl00`00
000007Go001eo`07001eo`0300000000MOl007Go00D007Go1`000008001I^P0300000000FKX005Vj
00T005Vj00D000000?ooo`3oool0oooo0000000j0?ooo`00AP3oool00`00000002R[000XZ`04000X
Z`0300000000::/002R[00H002R[00<00000000XZ`00::/02@00::/2000000<002R[00<00000000X
Z`00::/03`00::/5000000@007Go0P000006001eo`8000003P00MOl2000000X007Go0`000007001e
o`H000001@00MOl00`00000007Go001eo`08001eo`8000001@00MOl60000008005Vj00<00000001I
^P00FKX02@00FKX01@000000oooo0?ooo`3oool0000003X0oooo00160?ooo`0300000000::/002R[
008002R[0P000009000XZ`0300000000::/002R[00L002R[0P000005000XZ`0300000000::/002R[
00d002R[0P000005001eo`H000000`00MOl3000000h007Go0P00000:001eo`8000002000MOl20000
00L007Go1@0000001000MOl00000000000000003001eo`<000003@00MOl6000000P005Vj00D00000
0?ooo`3oool0oooo0000000j0?ooo`00@`3oool010000000oooo0?ooo`000002000XZ`8000002`00
::/00`00000002R[000XZ`05000XZ`8000001`00::/00`00000002R[000XZ`0;000XZ`8000001P00
MOl2000000D007Go1`00000;001eo`8000002P00MOl2000000P007Go0P000007001eo`8000002@00
MOl5000000`007Go0`000005001eo`H000000P00FKX01@000000oooo0?ooo`3oool0000003X0oooo
00130?ooo`030000003oool0oooo00<000003@00::/00`00000002R[000XZ`03000XZ`8000002@00
::/00`00000002R[000XZ`09000XZ`8000001`00MOl00`00000007Go001eo`04001eo`8000001P00
MOl60000008007Go0`000009001eo`<000001`00MOl3000000L007Go0P00000:001eo`8000001000
MOl00`00000007Go001eo`04000000<007Go0P00000>001eo`<000000`3oool00`000000oooo0?oo
o`0h0?ooo`00@P3oool01@000000oooo0?ooo`3oool0000000l002R[00@00000000XZ`00::/002R[
0P00000;000XZ`0300000000::/002R[00H002R[0`000005001eo`8000001`00MOl2000000h007Go
20000005001eo`0300000000MOl007Go00H007Go0P000007001eo`<000002P00MOl2000000h007Go
1000000>001eo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>03oool00480oooo00D0
00000?ooo`3oool0oooo0000000?000XZ`0400000000::/00000000000d002R[00<00000000XZ`00
::/01000::/2000000L007Go00<00000001eo`00MOl01@00MOl2000000h007Go0`000007001eo`@0
000000@007Go00000000000000000`00MOl3000000L007Go0P00000;001eo`8000003@00MOl30000
00H007Go0`000002001eo`D00000203oool00`000000oooo0?ooo`0h0?ooo`00AP3oool00`000000
02R[000XZ`0=000XZ`8000003`00::/00`00000002R[000XZ`02000XZ`8000003`00MOl2000000h0
07Go0`00000:001eo`0300000000MOl007Go00@007Go0`0000001000MOl00000000000000003001e
o`<000002P00MOl3000000d007Go0P00000>001eo`@0000000@0oooo00000000000000001@3oool0
0`000000oooo0?ooo`0h0?ooo`00@P3oool01@000000oooo0?ooo`3oool0000000h002R[0P00000@
000XZ`0300000000::/002R[008000002000MOl2000000D007Go0P00000>001eo`8000002P00MOl2
000000P007Go00<00000001eo`00MOl01000MOl5000000T007Go0P00000=001eo`<000003@00MOl3
000000P0oooo00<000000?ooo`0000000`00000j0?ooo`00@P3oool01@000000oooo0?ooo`3oool0
000000`002R[0P0000000`00::/00000000XZ`0?000XZ`<000002000MOl2000000@007Go0`00000>
001eo`8000002@00MOl2000000P007Go0P000008001eo`0300000000MOl007Go008007Go1@000002
001eo`8000003@00MOl2000000h007Go0P00000>0?ooo`030000003oool0oooo03X0oooo00120?oo
o`050000003oool0oooo0?ooo`0000002P00::/2000000<002R[00<00000000XZ`00::/03@00::/5
000000@007Go0P000005001eo`8000003`00MOl2000000T007Go0P000007001eo`8000002000MOl2
000000/007Go1P000009001eo`8000003@00MOl3000000`0oooo0P00000o0?ooo`00@P3oool01000
0000oooo0?ooo`000009000XZ`8000001@00::/00`00000002R[000XZ`0;000XZ`8000001@00MOl6
000000<007Go0P00000>001eo`<000002@00MOl2000000L007Go0P000007001eo`8000003@00MOl0
0`00000007Go001eo`04001eo`T000003@00MOl2000000h0oooo00<000000?ooo`3oool0?`3oool0
04D0oooo00<00000000XZ`00::/01@00::/2000000L002R[00<00000000XZ`00::/02@00::/20000
00H007Go0P000005001eo`H000002`00MOl3000000T007Go0P000007001eo`8000001`00MOl20000
00/007Go0P00000=001eo`8000000P00MOl7000000@007Go0`00000<0?ooo`800000A03oool004D0
oooo00<00000000XZ`00::/00`00::/2000000T002R[00<00000000XZ`00::/01`00::/2000000H0
07Go0P000006001eo`8000001@00MOl6000000@007Go00<00000001eo`00MOl01`00MOl3000000L0
07Go0P000007001eo`8000002P00MOl2000000h007Go0P00000;001eo`@000003P3oool00`000000
oooo0?ooo`140?ooo`00@P3oool010000000oooo0?ooo`000003000XZ`8000002`00::/00`000000
02R[000XZ`05000XZ`8000001P00MOl00`00000007Go001eo`05001eo`8000003@00MOl300000003
001eo`0000000000008000001000MOl2000000L007Go0`000007001eo`8000002@00MOl3000000d0
07Go0`00000<001eo`8000003@3oool2000004T0oooo00120?ooo`030000003oool0oooo00@00000
3@00::/00`00000002R[000XZ`03000XZ`8000001`00MOl00`00000007Go001eo`04001eo`800000
3P00MOl2000000L007Go100000001000MOl00000000000000003001eo`8000001`00MOl3000000T0
07Go0P00000>001eo`8000003000MOl3000000h0oooo00<000000?ooo`3oool0B@3oool00480oooo
00<000000?ooo`3oool00P00000?000XZ`0400000000::/002R[000XZ`8000002000MOl00`000000
07Go001eo`02001eo`<000003@00MOl3000000X007Go00<00000001eo`00MOl01000MOl300000004
001eo`0000000000000000<007Go0P000009001eo`<000001@00MOl00`00000007Go001eo`05001e
o`<000003000MOl2000000d0oooo0P00001>0?ooo`00A@3oool00`00000002R[000XZ`0>000XZ`04
00000000::/00000000000H007Go0P000005001eo`8000003P00MOl2000000T007Go0P000009001e
o`0300000000MOl007Go00@007Go0`0000001000MOl00000000000000004001eo`<000003P00MOl2
000000`007Go0`00000>0?ooo`030000003oool0oooo04h0oooo00150?ooo`0300000000::/002R[
00h002R[0P000007001eo`0300000000MOl007Go00<007Go0P00000>001eo`8000002@00MOl20000
00L007Go0P000009001eo`0300000000MOl007Go00@007Go100000001000MOl0000000000000000;
001eo`8000002`00MOl3000000d0oooo0P00001C0?ooo`00@P3oool010000000oooo0?ooo`00000>
000XZ`T000001P00MOl2000000h007Go0P000008001eo`<000001`00MOl2000000L007Go0P00000:
001eo`0300000000MOl007Go00@007Go2`00000;001eo`8000003`3oool00`000000oooo0?ooo`1C
0?ooo`00@P3oool010000000oooo0?ooo`00000<000XZ`8000001P00MOl9000000d007Go0`000008
001eo`8000001`00MOl3000000L007Go0P000008001eo`8000003`00MOl9000000@007Go0`00000=
0?ooo`800000F03oool00480oooo00@000000?ooo`3oool000002P00::/2000000@007Go0P000007
001eo`8000000P00MOl7000000@007Go0P000009001eo`8000001`00MOl2000000L007Go0`000008
001eo`8000003P00MOl3000000T007Go1000000?0?ooo`030000003oool0oooo05P0oooo00120?oo
o`040000003oool0oooo000000P002R[0P000005001eo`0300000000MOl007Go00D007Go0P00000;
001eo`@0000000@007Go00000000000000001000MOl3000000L007Go0P000007001eo`8000002000
MOl3000000h007Go0P00000;001eo`<000003@3oool2000005d0oooo00150?ooo`0300000000::/0
02R[00@002R[0P00000=001eo`8000003@00MOl2000000H007Go100000001000MOl0000000000000
0003001eo`<000001`00MOl2000000P007Go0P00000>001eo`<000002`00MOl2000000l0oooo00<0
00000?ooo`3oool0G@3oool00480oooo00@000000?ooo`3oool000001000::/2000000H007Go0P00
0004001eo`<000003@00MOl2000000P007Go0P000006001eo`<0000000@007Go0000000000000000
0`00MOl3000000P007Go0P00000>001eo`8000002`00MOl3000000d0oooo0P00001R0?ooo`00@P3o
ool010000000oooo0?ooo`000002000XZ`8000001P00MOl2000000@007Go0P00000>001eo`800000
2000MOl2000000P007Go00<00000001eo`00MOl01000MOl300000004001eo`0000000000000000@0
07Go0`00000=001eo`<000002`00MOl2000000l0oooo00<000000?ooo`3oool0HP3oool00480oooo
00<000000?ooo`3oool00`000005001eo`8000001@00MOl2000000h007Go0P000008001eo`800000
1`00MOl2000000P007Go00<00000001eo`00MOl01000MOl8000000X007Go0P00000;001eo`<00000
3@3oool2000006L0oooo00120?ooo`050000003oool0oooo00000000MOl00`0000000`00MOl00000
00000005001eo`8000003@00MOl3000000L007Go0`000007001eo`8000001`00MOl00`00000007Go
001eo`06001eo`<000001P00MOl:000000/007Go0P00000?0?ooo`030000003oool0oooo06L0oooo
00180?ooo`X000003@00MOl2000000P007Go0P000007001eo`<000001@00MOl3000000P007Go0P00
000>001eo`T000001000MOl3000000d0oooo0P00001/0?ooo`00AP3oool2000000X0oooo1`000004
001eo`8000002000MOl2000000L007Go0P000006001eo`8000002000MOl3000000h007Go0P000009
001eo`D000003@3oool2000006h0oooo00120?ooo`030000003oool0oooo01@0oooo20000005001e
o`0300000000MOl007Go00D007Go0P000006001eo`8000002000MOl2000000h007Go0`00000:001e
o`8000003P3oool200000740oooo00120?ooo`<00000703oool400000004001eo`00000000000000
00<007Go0P000005001eo`<000002000MOl2000000h007Go0P00000:001eo`<000003P3oool20000
07<0oooo00120?ooo`<000000P3oool3000001l0oooo0`0000000`00MOl0000000000008000000@0
07Go0`00000=001eo`<000002P00MOl2000000h0oooo0P00001f0?ooo`00BP3oool00`000000oooo
00000003000002L0oooo2000000:001eo`8000002P00MOl3000000/0oooo0P0000000`3oool00000
0000001h0?ooo`00DP3oool300000080oooo0`00000U0?ooo`X000002P00MOl2000000`0oooo0P00
001m0?ooo`00FP3oool00`000000oooo00000003000002D0oooo20000003001eo`<000002`3oool2
00000800oooo001R0?ooo`<000000P3oool3000002<0oooo0`00000<0?ooo`800000PP3oool006X0
oooo00<000000?ooo`0000000`00000Y0?ooo`800000Q@3oool00780oooo0`0000020?ooo`<00000
7@3oool2000008L0oooo001j0?ooo`030000003oool0000000<000003`3oool00`000000oooo0?oo
o`020?ooo`800000RP3oool00880oooo0`0000020?ooo`<000001@3oool00`000000oooo0?ooo`02
000008`0oooo002:0?ooo`030000003oool0000000@00000S`3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0346559, -0.0693066, \
0.00372582, 0.00372582}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[radFld[tt, "\<Bz\>", {0, y, 0}], {y, \(-per\)/2, per/2}, 
      PlotRange \[Rule] All]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.00414079 0.316155 0.594788 [
[.08592 .30366 -15.125 -14 ]
[.08592 .30366 15.125 0 ]
[.29296 .30366 -12.125 -14 ]
[.29296 .30366 12.125 0 ]
[.70704 .30366 -8 -14 ]
[.70704 .30366 8 0 ]
[.91408 .30366 -11 -14 ]
[.91408 .30366 11 0 ]
[.4875 .07824 -27.25 -7 ]
[.4875 .07824 0 7 ]
[.4875 .1972 -27.25 -7 ]
[.4875 .1972 0 7 ]
[.4875 .43511 -19 -7 ]
[.4875 .43511 0 7 ]
[.4875 .55407 -19 -7 ]
[.4875 .55407 0 7 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08592 .31616 m
.08592 .32241 L
s
gsave
.08592 .30366 -76.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.29296 .31616 m
.29296 .32241 L
s
gsave
.29296 .30366 -73.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.70704 .31616 m
.70704 .32241 L
s
gsave
.70704 .30366 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.91408 .31616 m
.91408 .32241 L
s
gsave
.91408 .30366 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
.12733 .31616 m
.12733 .31991 L
s
.16874 .31616 m
.16874 .31991 L
s
.21014 .31616 m
.21014 .31991 L
s
.25155 .31616 m
.25155 .31991 L
s
.33437 .31616 m
.33437 .31991 L
s
.37578 .31616 m
.37578 .31991 L
s
.41718 .31616 m
.41718 .31991 L
s
.45859 .31616 m
.45859 .31991 L
s
.54141 .31616 m
.54141 .31991 L
s
.58282 .31616 m
.58282 .31991 L
s
.62422 .31616 m
.62422 .31991 L
s
.66563 .31616 m
.66563 .31991 L
s
.74845 .31616 m
.74845 .31991 L
s
.78986 .31616 m
.78986 .31991 L
s
.83126 .31616 m
.83126 .31991 L
s
.87267 .31616 m
.87267 .31991 L
s
.04451 .31616 m
.04451 .31991 L
s
.00311 .31616 m
.00311 .31991 L
s
.95549 .31616 m
.95549 .31991 L
s
.99689 .31616 m
.99689 .31991 L
s
.25 Mabswid
0 .31616 m
1 .31616 L
s
.5 .07824 m
.50625 .07824 L
s
gsave
.4875 .07824 -88.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.5 .1972 m
.50625 .1972 L
s
gsave
.4875 .1972 -88.25 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 .43511 m
.50625 .43511 L
s
gsave
.4875 .43511 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.5 .55407 m
.50625 .55407 L
s
gsave
.4875 .55407 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .10798 m
.50375 .10798 L
s
.5 .13772 m
.50375 .13772 L
s
.5 .16746 m
.50375 .16746 L
s
.5 .22694 m
.50375 .22694 L
s
.5 .25668 m
.50375 .25668 L
s
.5 .28642 m
.50375 .28642 L
s
.5 .34589 m
.50375 .34589 L
s
.5 .37563 m
.50375 .37563 L
s
.5 .40537 m
.50375 .40537 L
s
.5 .46485 m
.50375 .46485 L
s
.5 .49459 m
.50375 .49459 L
s
.5 .52433 m
.50375 .52433 L
s
.5 .0485 m
.50375 .0485 L
s
.5 .01876 m
.50375 .01876 L
s
.5 .58381 m
.50375 .58381 L
s
.5 .61355 m
.50375 .61355 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .02899 m
.02499 .029 L
.02605 .02902 L
.02729 .02906 L
.02846 .02911 L
.03053 .02925 L
.03279 .02945 L
.03527 .02974 L
.0379 .03012 L
.04262 .03101 L
.04749 .03221 L
.05205 .0336 L
.06244 .0378 L
.07305 .04371 L
.08274 .0507 L
.10458 .07253 L
.12357 .09816 L
.14429 .1312 L
.18493 .19997 L
.22406 .26134 L
.26565 .32149 L
.30571 .37993 L
.34426 .44129 L
.38527 .51063 L
.40569 .54206 L
.42475 .56612 L
.44308 .5832 L
.45336 .59021 L
.46273 .59514 L
.46753 .59718 L
.47264 .599 L
.47705 .6003 L
.48181 .60143 L
.48447 .60195 L
.4869 .60235 L
.48938 .60268 L
.49168 .60293 L
.49421 .60313 L
.49555 .60321 L
.49698 .60327 L
.49771 .60329 L
.49849 .60331 L
.49923 .60332 L
.49991 .60332 L
.5012 .60331 L
.50185 .6033 L
.50257 .60328 L
.50386 .60324 L
.50506 .60318 L
.50638 .60309 L
Mistroke
.50778 .60298 L
.51038 .60271 L
.51273 .60241 L
.51752 .60158 L
.52202 .60056 L
.53206 .59736 L
.53772 .59496 L
.54291 .59235 L
.56177 .57928 L
.57247 .5691 L
.58245 .55775 L
.62141 .49946 L
.66282 .42922 L
.70272 .3666 L
.7411 .31058 L
.78194 .25014 L
.82126 .18626 L
.85906 .12057 L
.88007 .08664 L
.89931 .06061 L
.9182 .0412 L
.92769 .03374 L
.93805 .02717 L
.94773 .02239 L
.95651 .01906 L
.96137 .0176 L
.96664 .01631 L
.97161 .01536 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oS`3oool0
0`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000
oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?oo
o`220?ooo`@00000203oool008l0oooo0P0000200?ooo`<00000303oool008l0oooo00<000000?oo
o`3oool0O03oool3000000l0oooo002?0?ooo`030000003oool0oooo07T0oooo0`00000B0?ooo`00
1`3oool600000880oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0C0?ooo`003@3o
ool5000007d0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0D0?ooo`004P3oool2
000007/0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0E0?ooo`00503oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool05P3oool001D0
oooo0P00001h0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool05`3oool001L0oooo
00<000000?ooo`3oool0M@3oool2000007@0oooo00<000000?ooo`3oool0603oool001P0oooo00<0
00000?ooo`3oool0M03oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo01T0oooo000I
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0J
0?ooo`006P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool06`3oool001/0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo01`0oooo000L0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`0L0?ooo`007@3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool07@3oool001h0oooo00<000000?ooo`3oool0FP3oool3
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool07P3oool001h0oooo00<000000?ooo`3oool0F@3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1/
0?ooo`030000003oool0oooo01l0oooo000O0?ooo`030000003oool0oooo05P0oooo00D000000?oo
o`3oool0oooo000000040?ooo`H000001P3oool3000006`0oooo00<000000?ooo`3oool07`3oool0
0200oooo00<000000?ooo`3oool0D03oool8000000<0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0803oool0
0200oooo00<000000?ooo`3oool0E`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`000000203oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0240oooo000Q0?oo
o`030000003oool0oooo05H0oooo00D000000?ooo`3oool0oooo000000060?ooo`800000203oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0240oooo000Q0?ooo`030000003oool0oooo
05H0oooo00D000000?ooo`3oool0oooo000000060?ooo`800000203oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo0280oooo000R0?ooo`030000003oool0oooo05H0oooo0`0000080?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0S0?oo
o`008`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool08`3oool002<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1W0?ooo`030000
003oool0oooo02@0oooo000T0?ooo`030000003oool0oooo06P0oooo0P00001X0?ooo`030000003o
ool0oooo02@0oooo000U0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool09`3oool002P0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02P0oooo000Y0?oo
o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0X0?oo
o`00:@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0:@3oool002X0oooo00<000000?ooo`3oool0HP3oool200000680oooo00<000000?ooo`3oool0
:P3oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1Q0?ooo`030000003o
ool0oooo02X0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`0[0?ooo`00;03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0:`3oool002`0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0;@3oool002h0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02h0oooo000_0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`0^0?oo
o`00;`3oool00`000000oooo0?ooo`1M0?ooo`800000G@3oool00`000000oooo0?ooo`0_0?ooo`00
<03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
;`3oool00340oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo0300oooo000a0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`0a0?ooo`00<P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0<@3oool00380oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo0380oooo000c0?ooo`030000003oool0oooo04D0oooo
0`0000030?ooo`030000003oool0000000<00000203oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo0380oooo000d0?ooo`030000003oool0oooo04<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo03<0oooo000d0?ooo`030000003oool0oooo04<0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00P0oooo0`00001G0?ooo`030000003oool0oooo03@0
oooo000e0?ooo`030000003oool0oooo03/0oooo200000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo03@0oooo
000e0?ooo`030000003oool0oooo0480oooo00D000000?ooo`3oool0oooo000000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0e0?ooo`00=P3o
ool00`000000oooo0?ooo`110?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0=@3oool003L0oooo00<0
00000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03H0oooo000g0?ooo`030000
003oool0oooo0440oooo0`0000060?ooo`8000002@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0g0?ooo`00>@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool0>03oool003T0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo03P0oooo000j0?ooo`030000003oool0oooo0580
oooo0P00001C0?ooo`030000003oool0oooo03T0oooo000k0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0j0?ooo`00>`3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0>P3oool003`0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo03/0oooo000l0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0k0?oo
o`00?@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0?03oool003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo03d0oooo000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`0m0?ooo`00?`3oool00`000000oooo0?ooo`1=0?ooo`800000CP3oool0
0`000000oooo0?ooo`0n0?ooo`00@03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0?`3oool00400oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo03l0oooo00110?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`100?ooo`005P3oool300000080oooo0`00
00030?ooo`<000007P3oool00`000000oooo0?ooo`0=0?ooo`@000000`3oool3000003<0oooo00<0
00000?ooo`3oool0<P3oool4000000<0oooo0`00000>0?ooo`030000003oool0oooo0200oooo0`00
00020?ooo`<000000`3oool3000001<0oooo000G0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0100oooo
000G0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000030?ooo`030000003oool0oooo0100oooo000<0?ooo`L00000103oool010000000oooo
0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`040?ooo`L00000103oool00`000000oooo000000030?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0=P3oool00`000000oooo000000030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool0403oool001L0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo000000030?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0903oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0403oool0
01L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool02P3oool400000080oooo00D000000?ooo`3oool0oooo0000
000b0?ooo`800000<`3oool400000080oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000
003oool0oooo02@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`03
0000003oool0oooo0100oooo000G0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool000000380oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0U
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0@0?ooo`005P3oool2000000<0oooo0`0000030?ooo`<000008P3oool00`000000oooo0?ooo`0:
0?ooo`@000000P3oool3000003<0oooo00<000000?ooo`3oool0<`3oool400000080oooo0`000009
0?ooo`030000003oool0oooo02D0oooo0P0000030?ooo`<000000`3oool3000001<0oooo00170?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`170?oo
o`00B03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0A`3oool004P0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo04P0oooo00190?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`190?ooo`00BP3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool0B@3oool00?l00000800000010?ooo`0000<0oooo0000003o
ool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo0000000;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool1
00000040oooo0@3oool001P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool05`3oool004`0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04`0oooo001=0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1=0?ooo`00CP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0C@3o
ool004h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo04h0oooo001?0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`1?0?ooo`00D03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0C`3oool00500oooo00<000000?ooo`3oool0?03oool2000003`0oooo
00<000000?ooo`3oool0D03oool00540oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo0500oooo001B0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`1A0?ooo`00D`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0DP3oool005<0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0580oooo001D0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1C0?ooo`00E@3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0E03o
ool005D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo05@0oooo001F0?ooo`030000003oool0oooo03H0oooo0P00000g0?ooo`030000003oool0oooo
05D0oooo001G0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`1F0?ooo`00E`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0EP3oool005P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo05L0oooo001I0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`1H0?ooo`00F@3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0F03oool005X0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo05T0oooo001J0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1J0?ooo`00F`3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0FP3o
ool005`0oooo00<000000?ooo`3oool0<03oool200000340oooo00<000000?ooo`3oool0F`3oool0
05`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
05/0oooo001M0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`1L0?ooo`00G@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0G@3oool005h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo05d0oooo001O0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`1N0?ooo`00G`3oool00`000000oooo0?ooo`0I0?oo
o`<000000`3oool00`000000oooo00000003000000P0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`1O0?ooo`00H03oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`1O0?ooo`00H03oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo
0?ooo`0000001@3oool00`000000oooo0?ooo`080?ooo`<00000:`3oool00`000000oooo0?ooo`1P
0?ooo`00H@3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0H03oool0
0680oooo00<000000?ooo`3oool05@3oool01@000000oooo0?ooo`3oool0000000L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0640oooo001R0?oo
o`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1R0?ooo`00H`3oool00`00
0000oooo0?ooo`0D0?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00
00080?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<00000
0?ooo`3oool0503oool3000000H0oooo0P0000090?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0H`3oool006@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo06<0oooo001U0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`1T0?ooo`00I@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0I03oool006H0oooo00<000000?ooo`3oool09P3o
ool2000002L0oooo00<000000?ooo`3oool0I@3oool006L0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo06H0oooo001W0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1V0?ooo`00J03oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0I`3oool006P0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo06L0oooo
001Y0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1X0?ooo`00JP3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0J03oool006X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo06T0oooo001[0?ooo`030000003oool0oooo0240oooo0P00000R0?ooo`03
0000003oool0oooo06X0oooo001[0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1Z0?ooo`00K03oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0J`3oool006d0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06/0oooo001]0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1/0?ooo`00KP3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0K@3oool006h0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06d0oooo
001_0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1^0?ooo`00L03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0K`3oool00700oooo00<000000?ooo`3oool0703oool2000001d0oooo00<000000?oo
o`3oool0K`3oool00740oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0700oooo001b0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`1a0?ooo`00LP3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0LP3oool007<0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0780oooo001d0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1c0?ooo`00M03oool00`000000
oooo0?ooo`040?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1d0?ooo`00M@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0M03oool007H0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo0080oooo1P0000060?ooo`<000005P3oool00`000000
oooo0?ooo`1e0?ooo`00M`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
07H0oooo001g0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M`3oool007P0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`800000203oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo07P0oooo001i0?ooo`8000000`3oool00`000000oooo
0?ooo`040?ooo`800000203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo07T0oooo
001k0?ooo`<00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0NP3oool007`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo07/0oooo001m0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03P3oool2000007h0oooo001n0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`1n0?ooo`00O`3oool2000000h0oooo0P00000<0?ooo`800000
P@3oool00840oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0840oooo00220?ooo`8000002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0880oooo00240?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`800000Q@3oool008H0
oooo100000050?ooo`030000003oool0oooo00<0oooo100000270?ooo`00RP3oool;000008/0oooo
002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?oo
o`800000S`3oool008l0oooo00<000000?ooo`3oool0SP3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-121.049, -0.531548, \
0.84355, 0.00587262}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[radFld[tt, "\<Bz\>", {x, 0, 0}], {x, 0, 150}, 
        PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 -0.0555668 1.34714 [
[.15079 .06665 -8 -14 ]
[.15079 .06665 8 0 ]
[.27778 .06665 -8 -14 ]
[.27778 .06665 8 0 ]
[.40476 .06665 -8 -14 ]
[.40476 .06665 8 0 ]
[.53175 .06665 -8 -14 ]
[.53175 .06665 8 0 ]
[.65873 .06665 -11 -14 ]
[.65873 .06665 11 0 ]
[.78571 .06665 -11 -14 ]
[.78571 .06665 11 0 ]
[.9127 .06665 -11 -14 ]
[.9127 .06665 11 0 ]
[.01131 .21386 -19 -7 ]
[.01131 .21386 0 7 ]
[.01131 .34858 -19 -7 ]
[.01131 .34858 0 7 ]
[.01131 .48329 -19 -7 ]
[.01131 .48329 0 7 ]
[.01131 .618 -19 -7 ]
[.01131 .618 0 7 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .07915 m
.15079 .0854 L
s
gsave
.15079 .06665 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.27778 .07915 m
.27778 .0854 L
s
gsave
.27778 .06665 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.40476 .07915 m
.40476 .0854 L
s
gsave
.40476 .06665 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.53175 .07915 m
.53175 .0854 L
s
gsave
.53175 .06665 -69 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.65873 .07915 m
.65873 .0854 L
s
gsave
.65873 .06665 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.78571 .07915 m
.78571 .0854 L
s
gsave
.78571 .06665 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(120) show
1.000 setlinewidth
grestore
.9127 .07915 m
.9127 .0854 L
s
gsave
.9127 .06665 -72 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(140) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .07915 m
.05556 .0829 L
s
.0873 .07915 m
.0873 .0829 L
s
.11905 .07915 m
.11905 .0829 L
s
.18254 .07915 m
.18254 .0829 L
s
.21429 .07915 m
.21429 .0829 L
s
.24603 .07915 m
.24603 .0829 L
s
.30952 .07915 m
.30952 .0829 L
s
.34127 .07915 m
.34127 .0829 L
s
.37302 .07915 m
.37302 .0829 L
s
.43651 .07915 m
.43651 .0829 L
s
.46825 .07915 m
.46825 .0829 L
s
.5 .07915 m
.5 .0829 L
s
.56349 .07915 m
.56349 .0829 L
s
.59524 .07915 m
.59524 .0829 L
s
.62698 .07915 m
.62698 .0829 L
s
.69048 .07915 m
.69048 .0829 L
s
.72222 .07915 m
.72222 .0829 L
s
.75397 .07915 m
.75397 .0829 L
s
.81746 .07915 m
.81746 .0829 L
s
.84921 .07915 m
.84921 .0829 L
s
.88095 .07915 m
.88095 .0829 L
s
.94444 .07915 m
.94444 .0829 L
s
.97619 .07915 m
.97619 .0829 L
s
.25 Mabswid
0 .07915 m
1 .07915 L
s
.02381 .21386 m
.03006 .21386 L
s
gsave
.01131 .21386 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .34858 m
.03006 .34858 L
s
gsave
.01131 .34858 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
.02381 .48329 m
.03006 .48329 L
s
gsave
.01131 .48329 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .618 m
.03006 .618 L
s
gsave
.01131 .618 -80 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .10609 m
.02756 .10609 L
s
.02381 .13303 m
.02756 .13303 L
s
.02381 .15998 m
.02756 .15998 L
s
.02381 .18692 m
.02756 .18692 L
s
.02381 .2408 m
.02756 .2408 L
s
.02381 .26775 m
.02756 .26775 L
s
.02381 .29469 m
.02756 .29469 L
s
.02381 .32163 m
.02756 .32163 L
s
.02381 .37552 m
.02756 .37552 L
s
.02381 .40246 m
.02756 .40246 L
s
.02381 .4294 m
.02756 .4294 L
s
.02381 .45635 m
.02756 .45635 L
s
.02381 .51023 m
.02756 .51023 L
s
.02381 .53718 m
.02756 .53718 L
s
.02381 .56412 m
.02756 .56412 L
s
.02381 .59106 m
.02756 .59106 L
s
.02381 .0522 m
.02756 .0522 L
s
.02381 .02526 m
.02756 .02526 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .59483 m
.02499 .59483 L
.02605 .59484 L
.02729 .59484 L
.02846 .59485 L
.03053 .59487 L
.03279 .5949 L
.03527 .59495 L
.0379 .59501 L
.04262 .59514 L
.05205 .59552 L
.06244 .59608 L
.10458 .5993 L
.12562 .60095 L
.14487 .60219 L
.15437 .60265 L
.15939 .60285 L
.16474 .60302 L
.16988 .60315 L
.17454 .60324 L
.17679 .60327 L
.17798 .60328 L
.17923 .60329 L
.18032 .6033 L
.18152 .60331 L
.18262 .60331 L
.18364 .60332 L
.1849 .60332 L
.18554 .60332 L
.18624 .60332 L
.18748 .60332 L
.18865 .60331 L
.19001 .6033 L
.19127 .60329 L
.19409 .60326 L
.19639 .60323 L
.19891 .60319 L
.20399 .60307 L
.20864 .60293 L
.2136 .60276 L
.22255 .60237 L
.24389 .60112 L
.26405 .59967 L
.28236 .59832 L
.30251 .597 L
.31209 .5965 L
.32239 .59607 L
.32807 .59588 L
.33326 .59575 L
.33576 .5957 L
Mistroke
.33848 .59565 L
.34106 .59561 L
.34343 .59558 L
.34599 .59555 L
.34731 .59554 L
.34876 .59554 L
.35002 .59553 L
.3512 .59552 L
.35244 .59552 L
.35314 .59552 L
.35378 .59552 L
.35497 .59552 L
.35608 .59552 L
.3573 .59552 L
.35859 .59553 L
.35971 .59553 L
.36075 .59554 L
.36314 .59555 L
.36571 .59557 L
.36842 .59559 L
.37325 .59564 L
.38413 .59577 L
.38905 .59582 L
.3937 .59586 L
.39627 .59588 L
.39697 .59588 L
.39772 .59588 L
.39905 .59589 L
.40025 .59589 L
.40137 .59589 L
.40259 .59589 L
.40391 .59589 L
.40514 .59589 L
.40627 .59588 L
.40752 .59587 L
.40884 .59586 L
.41106 .59584 L
.41352 .5958 L
.41569 .59576 L
.41804 .59571 L
.42229 .59559 L
.42724 .59539 L
.43184 .59516 L
.43732 .5948 L
.44231 .5944 L
.4525 .59332 L
.4634 .59173 L
.47336 .58981 L
.48256 .58759 L
.50335 .58079 L
Mistroke
.52209 .57215 L
.54272 .55938 L
.56214 .54374 L
.58302 .52253 L
.62427 .46637 L
.664 .39675 L
.70221 .32321 L
.74288 .24823 L
.78203 .18559 L
.82363 .13111 L
.86371 .08941 L
.90228 .05767 L
.94331 .03131 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000F0?ooo`030000003oool0oooo0?l0
oooo203oool001H0oooo00<000000?ooo`3oool0o`3oool80?ooo`005P3oool00`000000oooo0?oo
o`3o0?ooo`P0oooo000F0?ooo`030000003oool0oooo0?h0oooo0P0000070?ooo`005P3oool00`00
0000oooo0?ooo`3l0?ooo`8000002@3oool001H0oooo00<000000?ooo`3oool0n@3oool3000000/0
oooo000F0?ooo`800000n03oool2000000h0oooo000F0?ooo`030000003oool0oooo0?D0oooo0P00
000@0?ooo`005P3oool00`000000oooo0?ooo`0I0?ooo`@000000`3oool3000001`0oooo00@00000
0?ooo`3oool0oooo0`00000I0?ooo`<000000`3oool3000001X0oooo0`0000030?ooo`<000005`3o
ool300000080oooo0`0000030?ooo`<00000503oool3000000030?ooo`0000000000008000000`3o
ool3000001D0oooo0`0000040?ooo`040000003oool0oooo0?ooo`<000004P3oool001H0oooo00<0
00000?ooo`3oool06@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`0I0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool05@3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo0?ooo`0F0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0180oooo00@000000?oo
o`3oool000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`03000000030?ooo`000000oooo0100oooo000F0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000001P0oooo1`0000030?ooo`030000003oool0oooo01D0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`3oool05P3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000`3oool00`000000oooo0?ooo`0E0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`000000103o
ool01@000000oooo0?ooo`3oool0000001D0oooo00<000000?ooo`3oool01`0000030?ooo`030000
003oool0oooo00l0oooo000F0?ooo`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool01@000000
oooo0?ooo`3oool0000001L0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`3oool05P3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000
oooo0?ooo`0E0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`00
0000oooo0080oooo00<000000?ooo`3oool03`3oool001H0oooo00<000000?ooo`3oool0703oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`0000000P3o
ool01@000000oooo0?ooo`3oool0000001L0oooo100000020?ooo`050000003oool0oooo0?ooo`00
00006@3oool300000080oooo00D000000?ooo`3oool0oooo0000000G0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0C0?ooo`040000003o
ool0oooo0?ooo`<000000P3oool01@000000oooo0?ooo`3oool000000140oooo000F0?ooo`800000
7@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01P0oooo0P0000020?ooo`05
0000003oool0oooo0?ooo`000000603oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`000000603oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo
0?ooo`0E0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`0C0?ooo`040000003oool0oooo0?ooo`<000000P3oool01@000000oooo0?ooo`3o
ool000000140oooo000F0?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`3oool0000001X0oooo0P0000020?ooo`050000003oool0oooo0?ooo`00
0000603oool2000000<0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo000000030?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01<0oooo00D000000?oo
o`00000000000?ooo`0200000080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`005P3oool0
0`000000oooo0?ooo`0J0?ooo`800000103oool3000001`0oooo00@000000?ooo`3oool0oooo0`00
000K0?ooo`8000000P3oool3000001X0oooo0`0000030?ooo`<000005`3oool2000000<0oooo0`00
00030?ooo`<00000503oool2000000<0oooo0P0000040?ooo`<000005@3oool3000000@0oooo00@0
00000?ooo`3oool0oooo0`00000B0?ooo`005P3oool00`000000oooo0?ooo`3X0?ooo`030000003o
ool0oooo01`0oooo000F0?ooo`030000003oool0oooo0>L0oooo00<000000?ooo`3oool07@3oool0
01H0oooo00<000000?ooo`3oool0iP3oool00`000000oooo0?ooo`0N0?ooo`005P3oool00`000000
oooo0?ooo`3U0?ooo`030000003oool0oooo01l0oooo000?0?ooool000004P00000001H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool01@3oool001H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01H0oooo000F0?ooo`030000003oool0oooo0>40oooo00<000000?oo
o`3oool08`3oool001H0oooo00<000000?ooo`3oool0h03oool00`000000oooo0?ooo`0T0?ooo`00
5P3oool00`000000oooo0?ooo`3O0?ooo`030000003oool0oooo02D0oooo000F0?ooo`030000003o
ool0oooo0=h0oooo00<000000?ooo`3oool09P3oool001H0oooo00<000000?ooo`3oool0g@3oool0
0`000000oooo0?ooo`0W0?ooo`005P3oool200000=d0oooo00<000000?ooo`3oool0:03oool001H0
oooo00<000000?ooo`3oool0f`3oool00`000000oooo0?ooo`0Y0?ooo`005P3oool00`000000oooo
0?ooo`3J0?ooo`030000003oool0oooo02X0oooo000F0?ooo`030000003oool0oooo0=T0oooo00<0
00000?ooo`3oool0:`3oool001H0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`0/
0?ooo`005P3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo02d0oooo000F0?ooo`03
0000003oool0oooo0=H0oooo00<000000?ooo`3oool0;P3oool001H0oooo0P00003G0?ooo`030000
003oool0oooo02h0oooo000F0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0;`3o
ool001H0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0`0?ooo`005P3oool00`00
0000oooo0?ooo`3C0?ooo`030000003oool0oooo0340oooo000F0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool0<P3oool001H0oooo00<000000?ooo`3oool0dP3oool00`000000oooo
0?ooo`0b0?ooo`005P3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo03<0oooo000F
0?ooo`800000d@3oool00`000000oooo0?ooo`0d0?ooo`005P3oool00`000000oooo0?ooo`3?0?oo
o`030000003oool0oooo03D0oooo000F0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3o
ool0=P3oool001H0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0f0?ooo`005P3o
ool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo03L0oooo000F0?ooo`030000003oool0
oooo0<`0oooo00<000000?ooo`3oool0>03oool001H0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0i0?ooo`005P3oool200000</0oooo00<000000?ooo`3oool0>P3oool001H0oooo
00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0j0?ooo`005P3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo03/0oooo000F0?ooo`030000003oool0oooo0<T0oooo00<00000
0?ooo`3oool0>`3oool001H0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0l0?oo
o`005P3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo03d0oooo00030?ooo`<00000
0`3oool00`000000oooo00000003000000L0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0m0?ooo`000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0?P3oool00080oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo0`0000360?ooo`03
0000003oool0oooo03h0oooo00020?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0?`3oool00080oooo
00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0a03oool00`000000oooo0?ooo`100?ooo`000P3oool01@000000oooo0?ooo`3oool0000000L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo0400
oooo00020?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000070?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0@@3oool000<0oooo0`0000060?ooo`80
0000203oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0440oooo000F0?ooo`030000
003oool0oooo0<80oooo00<000000?ooo`3oool0@P3oool001H0oooo0P0000320?ooo`030000003o
ool0oooo04<0oooo000F0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0@`3oool0
01H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`140?ooo`005P3oool00`000000
oooo0?ooo`300?ooo`030000003oool0oooo04@0oooo000F0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0A@3oool001H0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?oo
o`150?ooo`005P3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo04H0oooo000F0?oo
o`800000_`3oool00`000000oooo0?ooo`160?ooo`005P3oool00`000000oooo0?ooo`2m0?ooo`03
0000003oool0oooo04L0oooo000F0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
B03oool001H0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`180?ooo`005P3oool0
0`000000oooo0?ooo`2k0?ooo`030000003oool0oooo04T0oooo000F0?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool0B@3oool001H0oooo00<000000?ooo`3oool0^P3oool00`000000
oooo0?ooo`1:0?ooo`005P3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo04X0oooo
000F0?ooo`800000^P3oool00`000000oooo0?ooo`1;0?ooo`005P3oool00`000000oooo0?ooo`2i
0?ooo`030000003oool0oooo04/0oooo000F0?ooo`030000003oool0oooo0;P0oooo00<000000?oo
o`3oool0C03oool001H0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`1=0?ooo`00
5P3oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo04d0oooo000F0?ooo`030000003o
ool0oooo0;H0oooo00<000000?ooo`3oool0CP3oool001H0oooo00<000000?ooo`3oool0]P3oool0
0`000000oooo0?ooo`1>0?ooo`005P3oool200000;H0oooo00<000000?ooo`3oool0C`3oool001H0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`1?0?ooo`005P3oool00`000000oooo
0?ooo`2d0?ooo`030000003oool0oooo0500oooo000F0?ooo`030000003oool0oooo0;@0oooo00<0
00000?ooo`3oool0D03oool001H0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`1A
0?ooo`000`3oool3000000<0oooo00<000000?ooo`0000000`0000070?ooo`030000003oool0oooo
0;<0oooo00<000000?ooo`3oool0D@3oool00080oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`1B0?oo
o`000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0103oool30000
0;40oooo00<000000?ooo`3oool0D`3oool00080oooo00D000000?ooo`3oool0oooo000000080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`1C0?oo
o`000P3oool01@000000oooo0?ooo`3oool0000000D0oooo0`0000070?ooo`030000003oool0oooo
0;00oooo00<000000?ooo`3oool0E03oool00080oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`1D0?oo
o`000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0E@3oool000<0oooo0`0000060?oo
o`<000001`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo05D0oooo000F0?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool0EP3oool001H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`1F0?ooo`005P3oool200000:h0oooo00<000000?ooo`3oool0E`3o
ool001H0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`1H0?ooo`005P3oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo05P0oooo000F0?ooo`030000003oool0oooo0:/0
oooo00<000000?ooo`3oool0F@3oool001H0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`1I0?ooo`005P3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo05X0oooo000F
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0FP3oool001H0oooo0P00002Z0?oo
o`030000003oool0oooo05/0oooo000F0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool0F`3oool001H0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`1L0?ooo`005P3o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo05`0oooo000F0?ooo`030000003oool0
oooo0:L0oooo00<000000?ooo`3oool0G@3oool001H0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`1M0?ooo`005P3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo05h0
oooo000F0?ooo`800000Y`3oool00`000000oooo0?ooo`1N0?ooo`005P3oool00`000000oooo0?oo
o`2U0?ooo`030000003oool0oooo05l0oooo000F0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0H03oool001H0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`1P0?oo
o`005P3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo0640oooo000F0?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`3oool0H@3oool001H0oooo00<000000?ooo`3oool0XP3o
ool00`000000oooo0?ooo`1R0?ooo`005P3oool200000:<0oooo00<000000?ooo`3oool0HP3oool0
01H0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`1S0?ooo`005P3oool00`000000
oooo0?ooo`2Q0?ooo`030000003oool0oooo06<0oooo000F0?ooo`030000003oool0oooo0:00oooo
00<000000?ooo`3oool0I03oool001H0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?oo
o`1T0?ooo`005P3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo06D0oooo00030?oo
o`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0WP3oool00`000000oooo0?ooo`1V0?ooo`000P3oool01@000000oooo0?ooo`3oool00000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo
06L0oooo00020?ooo`050000003oool0oooo0?ooo`000000103oool6000000D0oooo0`00002L0?oo
o`030000003oool0oooo06P0oooo00020?ooo`050000003oool0oooo0?ooo`000000103oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0J03oool0
0080oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`1Y0?ooo`000P3oool01@000000oooo0?ooo`3oool0
000000H0oooo0P0000070?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0JP3oool0
0080oooo00D000000?ooo`3oool0oooo000000060?ooo`8000001`3oool00`000000oooo0?ooo`2I
0?ooo`030000003oool0oooo06/0oooo00030?ooo`<00000203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo09P0oooo00<000000?ooo`3oool0K03oool001H0oooo00<000000?ooo`3o
ool0V03oool00`000000oooo0?ooo`1/0?ooo`005P3oool2000009P0oooo00<000000?ooo`3oool0
K@3oool001H0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1^0?ooo`005P3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo06l0oooo000F0?ooo`030000003oool0oooo
09@0oooo00<000000?ooo`3oool0L03oool001H0oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`1`0?ooo`005P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0740oooo
000F0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0LP3oool001H0oooo0P00002B
0?ooo`030000003oool0oooo07<0oooo000F0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0M03oool001H0oooo00<000000?ooo`3oool0SP3oool2000007L0oooo000F0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0M`3oool001H0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`1h0?ooo`005P3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo07T0oooo000F0?ooo`030000003oool0oooo08T0oooo0P00001l0?ooo`005P3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo07`0oooo000F0?ooo`800000Q`3oool2000007l0oooo
000F0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0O`3oool001H0oooo00<00000
0?ooo`3oool0P`3oool200000880oooo000F0?ooo`030000003oool0oooo0800oooo0`0000240?oo
o`005P3oool00`000000oooo0?ooo`1n0?ooo`800000Q`3oool001H0oooo00<000000?ooo`3oool0
N`3oool3000008T0oooo000F0?ooo`030000003oool0oooo07P0oooo0`00002<0?ooo`005P3oool2
000007@0oooo1@00002?0?ooo`005P3ooolA000003`0oooo:@00002D0?ooo`005P3oool00`000000
oooo0?ooo`0>0?ooo`T000009@3oool>00000;d0oooo000F0?ooo`030000003oool0oooo01L0oooo
9@00003;0?ooo`005P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo00030?ooo`<000000`3oool0
0`000000oooo00000003000000L0oooo00<000000?ooo`3oool0o`3oool80?ooo`000P3oool01@00
0000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o
0?ooo`P0oooo00020?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`04
0?ooo`<00000o`3oool80?ooo`000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`000P3oool01@000000oooo0?ooo`3oool0000000@0oooo1000003o
0?oooa80oooo00020?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`3o
0?oooa80oooo00030?ooo`<000001P3oool400000?l0oooo4@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-13.0093, 0.0379336, \
0.581045, 0.00273853}}]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 1004}},
WindowSize->{767, 767},
WindowMargins->{{102, Automatic}, {Automatic, 98}},
ShowCellLabel->False,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
0@00D01804P000000]X2:?oQon82n@96D005:0?l0040D01804P000000]X2:000
0000I0000000000000000BL?00400@00000000000000000B0002I0000aP00000
8W800@0100<00P0000000000oW`10000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 65, 1, 62, "Title"],
Cell[1785, 52, 56, 0, 26, "Text"],
Cell[1844, 54, 665, 11, 142, "Text"],

Cell[CellGroupData[{
Cell[2534, 69, 33, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2592, 73, 109, 2, 63, "Input"],
Cell[2704, 77, 220, 4, 22, "Print"],
Cell[2927, 83, 121, 2, 37, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3097, 91, 27, 0, 59, "Section"],
Cell[3127, 93, 2682, 43, 751, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5846, 141, 24, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[5895, 145, 3597, 64, 623, "Input"],
Cell[9495, 211, 240, 4, 22, "Print"],
Cell[9738, 217, 214, 4, 22, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10001, 227, 27, 0, 39, "Section"],
Cell[10031, 229, 55, 1, 47, "Input"],
Cell[10089, 232, 62, 1, 47, "Input"],
Cell[10154, 235, 62, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[10241, 240, 118, 2, 63, "Input"],
Cell[10362, 244, 148431, 4878, 296, 64799, 3841, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[158842, 5128, 24, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[158891, 5132, 124, 2, 47, "Input"],
Cell[159018, 5136, 28874, 786, 186, 9218, 539, "GraphicsData", "PostScript", \
"Graphics"],
Cell[187895, 5924, 130, 3, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[188062, 5932, 120, 2, 47, "Input"],
Cell[188185, 5936, 27824, 873, 186, 11273, 664, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

